* **************************************************************************** *
* **************************************************************************** *
* Women's Labor Force Participation in Nepal:                                  *
* An Exploration of The Role of Social Norms                                   *
* Replication .do files 													   * 
* Misc: Data Analysis .do file                                                  *
* 2024                                                                         *
* **************************************************************************** *
* **************************************************************************** *

/*
* Author: Aishwarya Patil & Jyotirmoy Saha
* Program Purpose: This dofile reproduces analyses reported in Tables A.1 and
*                  A.2 in the annex to the paper. 
* Description: Key tasks performed by this dofile include:
- Generates Tables A.1 and A.2 included in the annex to the paper.  
*
* Date last modified: June 2024
*------------------------------------------------------------------------------*
* Datasets Required: 
* - Nepal_LFS_2018 (Dataset not included, refer to README for details)
*
* Outline: 
*  Part 1. Generate Tables A.1 and A.2.   
*/


********************************************************************************
*                       PREPARATION AND MAIN SETTINGS 
********************************************************************************
clear all
capture log close
set mem 100m
set more off

*Load dataset 
 use "C:\Users\wb556220\OneDrive - WBG\Nepal social norms study\QUANT-Analysis\NLFS-III\data\final\Nepal_LFS_2018.dta", clear

********************************************************************************
*                       CLEAN RELEVANT VARIABLES							   *
********************************************************************************

*Working age population
gen w_age_pop = . 
replace w_age_pop = 1 if age>=15 & age<=64
replace w_age_pop= 0 if age<15 | age>64
label var w_age_pop "Working Age Population 15-64"
tab w_age_pop [aw=weight]


** Employment Status **
capture drop arc_employed
gen arc_employed = 0						                                    //work for wage or profit or own production
	replace arc_employed=1 if wrk_paid==1 |temp_absent==1 
	replace arc_employed=1 if wrk_busns==1 |temp_absent==1
	replace arc_employed=1 if wrk_unpaid==1
	replace arc_employed=0 if return_prd==3
	replace arc_employed=0 if  purp_agripdct==3|purp_agripdct==4
	tab arc_employed 


capture drop arc_paidemployed	
gen arc_paidemployed=.
	replace arc_paidemployed=0 if arc_employed==1
	replace arc_paidemployed=1 if mwrk_status==1|mwrk_status==2
	tab arc_paidemployed [aw=weight]
	 
capture drop arc_selfemployed
gen arc_selfemployed=.
	replace arc_selfemployed=0 if arc_employed==1
	replace arc_selfemployed=1 if mwrk_status==3|mwrk_status==4
	tab arc_selfemployed [aw=weight]
	
capture drop arc_unpaid
gen arc_unpaid=.
	replace arc_unpaid=0 if arc_employed==1
	replace arc_unpaid=1 if mwrk_status==5|mwrk_status==6
	tab arc_unpaid [aw=weight]
	
	
capture drop arc_w_contract
gen arc_w_contract=.
replace arc_w_contract= 0 if arc_employed==1
replace arc_w_contract= 1 if mwrk_cnrt_basis==1
la var arc_w_contract "Written contract"
tab  arc_w_contract [aw=weight]


capture drop arc_emp_de 
gen arc_emp_de=.
	replace arc_emp_de=1 if arc_paidemployed==1
	replace arc_emp_de=2 if arc_selfemployed==1
	replace arc_emp_de=3 if arc_unpaid==1
label define status 1"paid employed" 2 "self employed" 3"unpaid family worker"
label values arc_emp_de status

tab arc_emp_de [aw=weight]
 
 
**Creation of Sector**
capture drop sector
gen sector=.
replace sector=1 if inrange(mwrk_nsic4,111,322) //Agriculture 
replace sector=2 if inrange(mwrk_nsic4,520,4390) //Manufacturing
replace sector=3 if inrange(mwrk_nsic4,4510,9900) // Services
label define industry 1"Agriculture" 2 "Industry" 3"Service", replace
label values sector industry 
tab sector [aw=weight] 


** Employment Status in details**
capture drop employment_status 
gen employment_status=.
replace employment_status=1 if arc_employed==1 & arc_w_contract==1 // Wage formal
replace employment_status=2 if arc_employed==1 & arc_w_contract==0 // Wage Informal
replace employment_status=3 if arc_unpaid==1 // Unpaid Family worker
replace employment_status=4 if arc_selfemployed==1 & sector==1 // Self Agri
replace employment_status=5 if arc_selfemployed==1 & (sector==2|sector==3) // Self Non-Agri
label define employment 1 "Wage Formal" 2 "Wage Informal" 3 "Unpaid Family Worker" 4 "Self Agri" 5 "Self Non-Agri", replace
label values employment_status employment 
tab employment_status [aw=weight]


** Formal vs Informal Wage**
capture drop wage_informal
gen wage_informal=.
replace wage_informal=1 if employment_status==2
replace wage_informal=0 if employment_status==1
label define informal 1 "Wage Informal" 0 "Wage Formal", replace
label values wage_informal informal
tab wage_informal employment_status

**Wage formal vs (Wage informal+Unpaid Family Worker)
capture drop wage_unpaid_informal
gen wage_unpaid_informal=.
replace wage_unpaid_informal=1 if employment_status==2|employment_status==3
replace wage_unpaid_informal=0 if employment_status==1

label define formal_emp1 0" Wage Formal Job" 1 "Wage Informal+Unpaid Family Worker"
label values wage_unpaid_informal formal_emp1
tab wage_unpaid_informal


**Wage Informal vs Self Employed
capture drop informal_self
gen informal_self=.
replace informal_self=1 if employment_status==4|employment_status==5
replace informal_self=0 if employment_status==2
label define self 1"Self Employment (agri+non-agri)" 0 "Wage Informal"
label values informal_self self
tab informal_self



********************************************************************************
*                       GENERATE TABLES							               *
********************************************************************************

*--Table A.1--**
*-----What is the main reason why you did not try to find a paid job or start a business in the last 30 days?--***
tabout rsn_nteffort if sex==2 [aw=weight] using "C:\Users\wb556220\OneDrive - WBG\Nepal social norms study\QUANT-Analysis\NLFS-III\output\annexA.1.xls", replace c(freq col row) format(0c 1p 1p) layout(cb)

*--Table A.2--***
tabout employment_status sex [iweight=weight] using "C:\Users\wb556220\OneDrive - WBG\Nepal social norms study\QUANT-Analysis\NLFS-III\output\annexA.2.xls", replace c(freq col row) format(0c 1p 1p) layout(cb)


********************************************************************************
// END OF DOFILE


