* **************************************************************************** *
* **************************************************************************** *
* Women's Labor Force Participation in Nepal:                                  *
* An Exploration of The Role of Social Norms                                   *
* Replication .do files 													   * 
* 01: Data Cleaning .do file                                                   *
* 2024                                                                         *
* **************************************************************************** *
* **************************************************************************** *

/*
* Author: Aishwarya Patil
* Program Purpose: This dofile cleans and prepares the data for variable construction. 
* Description: Key tasks performed by this dofile include:
- Adds value and variable lables 
- Generates new variables 
- Converts string to numeric variables and vice-versava when needed
- Merges household and individual level variables  

* Date last modified: May 2024
*------------------------------------------------------------------------------*
* Datasets Required: 
- men_women_roster_main.dta
- women_roster_main.dta
*
* Unique Identificator: 
- ID
*
* Outline: 
*  Part 1. Clean variables in the individual-level dataset, save .dta file 
*  Part 2. Clean variables in the household-level dataset, save .dta file  
*  Part 3. Merge household-level variables with individual-level dataset, save .dta file
*/

********************************************************************************
*                       PREPARATION AND MAIN SETTINGS 
********************************************************************************
if 1 {
* Index of parts
* -----------------  
  gl part_1    1   	// Cleaning individual-level variables
  gl part_2    1    // Cleaning household-level variables
  gl part_3    1    // Merging individual and household-level variables
  
}


********************************************************************************
*                  PART 1. Cleaning individual-level variables 				   *
********************************************************************************

if $part_1 {
	
*Load dataset 
 use "$data\raw\men_women_roster_main.dta", clear

*define labels 
 label define yesno 1 "yes" 0 "no"

 
/**** ID variables ****/
*HH ID
 *codebook HH_2			//unique = 1150 == # non-migrant HHs
 clonevar ID_HH = HH_2											
 recast str30 ID_HH, force

*Individual ID
 *isid HH_21				//unique
 clonevar ID = HH_21
 recast str30 ID, force

*Identify couples 
 duplicates tag ID_HH, gen(couple)  
 label define couple 0 "only female (spouse of migrant man)" 1 "couple"
 lab val couple couple 
 lab var couple "Identifier for couples: 1 if respondent is part of a couple interviewed"
 *codebook couple

 
/**** Background and household characteristics variables ****/

/*notes*/
*quota 
 rename QUOTA quota 
 label var quota "Target category of respondent"

*notes
 recast str2045 OUTLIER_NOTES, force
 rename OUTLIER_NOTES notes
 replace notes=trim(notes)

*comments 
 recast str2045 COMMENTS, force
 rename COMMENTS comments 
 replace comments=trim(comments)
 replace comments = "" if inlist(comments,"NA","No","No comments","No.","None") | inlist(comments,"None.","na","no","no comment","no comments","none","none.")

/*demographics*/
*ecological zone 			
 rename HH_22 ecological_zone

*Province
 rename HH_23 province 

*district 
 rename HH_24 district 

*city/municipality 
 rename HH_25 cityORmunicipality

*locality 
 rename HH_26 locality 

*PSU (ward)
 rename ward PSU

*gender 
 rename HL2 gender 

*age 
 rename HL3 age
 label var age "Age of self, in years"
*age categories 
 recode age (18/24 =1) (25/34 =2) (35/45 =3) (46/55 =4) (56/90 =5), gen (age_cat)
 label define age 1 "18 to 24"  2 "25 to 34" 3 "35 to 45" 4 "46 to 55" 5 "56 and older"
 lab val age_cat age
 lab var age_cat "Age groups - self , in years" 

*head of HH status 
 rename HL5 hh_head_status 
 recode hh_head_status (2=0) 
 label val hh_head_status yesno

*religion - female 
 rename HH_27_FEMALE religion_female
 recode religion_female (96=1) //Prakriti as Hinduisum

*religion - male 	
 rename HH_27_MALE religion_male
 recode religion_male (96=1) ////Prakriti as Hinduisum		
 
*religion - family 
 clonevar religion_family = religion_female 
 replace religion_family = religion_male if missing(religion_female)
 replace religion_family = 6 if inlist(ID_HH, "HH5653", "HH5445", "HH6126")			//verified by phone calls that husband and wife follow different religions
 label define religion_family 1 "Hindu" 2 "Buddhist" 3 "Muslim" 5 "Christian" 6 "Hindu/Christian"
 label value religion_family religion_family  

*ethnicity
 rename AGG_HH_28 ethnicity
 
*education 
 rename HH_29 education

/*migrant spouse details*/
*migration status
 rename HH_219A_MALE migrationstatus_male_self
 label var migrationstatus_male_self "Migration status of self, male"
 recode migrationstatus_male_self (1/5 = 1 "Migrated") (6 = 0 "Never migrated"), gen(ever_migrated_male)
 label var ever_migrated_male "Dummy for male ever migrated, domestic or int."
 
 rename HH_219A_FEMALE migrationstatus_spouse
 label var migrationstatus_spouse "Status of husband's migration, reported by female"
 
 recode migrationstatus_spouse (1/5 = 1 "Migrated") (6 = 0 "Never migrated"), gen(ever_migrated_spouse)
 label var ever_migrated_spouse "Dummy for spouse ever migrated, domestic or int."
 
 recode migrationstatus_spouse (1 6 = 0 "Never migrated or not in the past 12 months") (2/5 = 1 "Migrated"), gen(migrationstatus_spouse_dummy)
 label var migrationstatus_spouse_dummy "Dummy for migration status of spouse"

*age										
 gen migrantspouse_age = HH_219C								 
 label var migrantspouse_age "Migrant husband's age"
 codebook migrantspouse_age
  
*age categories 
 recode migrantspouse_age (18/24 =1) (25/34 =2) (35/45 =3) (46/55 =4) (56/90 =5), gen (migrantspouse_age_cat)
 lab val migrantspouse_age_cat age
 lab var migrantspouse_age_cat "Migrant husband's age group"  

*education											
 clonevar migrantspouse_education = HH_219D								 
 label var migrantspouse_education "Migrant husband's highest education level"

*location of migration 
 recast str30 HH_219E, force
 encode HH_219E, gen(migrantspouse_location) label(HH_219Elabel)
 replace migrantspouse_location = . if migrantspouse_location == 1
 label var migrantspouse_location "Migrant husband's location (city/municipality/country) of migration"

*country of migration 
 recode migrantspouse_location (2 3 7 8 9 11 12 13 16 20 26 = 1 "Nepal") (4 = 2 "India") (5 = 3 "Japan") (6 = 4 "Jordan") (10 = 5 "Kuwait") (14 = 6 "Malaysia") (15 = 7 "Malta") (17 = 8 "Oman") (18 = 9 "Portugal") (19 = 10 "Qatar") (21 = 11 "Romania") (23 = 12 "South Korea") (22 = 13 "Saudi Arabia") (24 = 14 "Spain") (25 = 15 "UAE"), gen(migrantspouse_country)
 label var migrantspouse_country "Migrant husband's country of migration"

*reason for migration 
 clonevar migrantspouse_reason = HH_219F								    
 label var migrantspouse_reason "Migrant husband's reason for migration"

*description of work
 recast str2045 HH_219G, force
 clonevar migrantspouse_workdesc = HH_219G
 label var migrantspouse_workdesc "Migrant husband's description of work"

*NSCO and NSIC codes 
 rename HH_219G_NSCO migrantspouse_workdesc_NSCO 
 rename HH_219G_NSIC migrantspouse_workdesc_NSIC
 label var migrantspouse_workdesc_NSCO "NSCO codes for migrantspouse_workdesc"
 label var migrantspouse_workdesc_NSIC "NSIC codes for migrantspouse_workdesc"
*aggregate codes
 recode migrantspouse_workdesc_NSCO ///
	(110/310 = 1 "Armed forces occupations") ///
	(1111/1439 = 2 "Managers") ///
	(2111/2659 = 3 "Professionals") ///
	(3111/3522 = 4 "Technicians and associate professionals") ///
	(4110/4419 = 5 "Clerical support workers") ///
	(5111/5419 = 6 "Service and sales workers") ///
	(6111/6340 = 7 "Skilled agricultural, forestry and fishery workers") ///
	(7111/7549 = 8 "Craft and related trades workers") ///
	(8111/8350 = 9 "Plant and machine operators and assemblers") ///
	(9111/9629 = 10 "Elementary occupations") ///
 , gen(migrantspouse_workdesc_NSCO_agg)
 label var migrantspouse_workdesc_NSCO_agg "Aggregated NSCO codes for migrantspouse_workdesc"

 recode migrantspouse_workdesc_NSIC ///
	(111/322 = 1 "Agriculture, forestry and fishing") ///
	(510/990 = 2 "Mining and Quarrying") ///
	(1010/3320 = 3 "Manufacturing") ///
	(3510/3530 = 4 "Electricity, gas, steam and air conditioning supply") ///
	(3600/3900 = 5 "Water supply; sewerage, waste management and remediation activities") ///
	(4100/4390 = 6 "Construction") ///
	(4510/4799 = 7 "Wholesale and retail trade; repair of motor vehicles and motorcycles") ///
	(4911/5320 = 8 "Transportation and Storage") ///
	(5510/5630 = 9 "Accommodation and food services activities") ///
	(5811/6399 = 10 "Information and Communication") ///
	(6411/6630 = 11 "Financial and insurance activities") ///
	(6810/6820 = 12 "Real estate business activities") ///
	(6910/7500 = 13 "Prrofessional, scientific and technical activities") ///
	(7710/8299 = 14 "Administrative and Support Service Activities") ///
	(8411/8430 = 15 "Public administration and defense; compulsory social security") ///
	(8510/8550 = 16 "Education") ///
	(8610/8890 = 17 "Human health and social work activities") ///
	(9000/9329 = 18 "Arts, entertainment and recreation") ///
	(9411/9609 = 19 "Other service activities") ///
	(9700/9820 = 20 "Activities of households as employers; undifferentiated goods and services producing activities of households for own use") ///
	(9900 = 21 "Activities of Extra-territorial organizations and bodies)") ///
 , gen(migrantspouse_workdesc_NSIC_agg)
 label var migrantspouse_workdesc_NSIC_agg "Aggregated NSIC codes for migrantspouse_workdesc"

/*HH Info*/
*number of members 
 gen hh_members = HH_220
 label var hh_members "Total number of HH members"

*number of minors 
 gen hh_minors = HH_221
 label var hh_minors "Total number of minors (under 18 years)"

*number of seniors
 gen hh_seniors = HH_222
 label var hh_seniors "Total number seniors (above 60 years)"

*number of disabled
 gen hh_disabled = HH_223
 label var hh_disabled "Total number of disabled HH members"

*number of current migrants
 gen hh_migrants = HH_224
 label var hh_migrants "Total number of HH members currently migrated, thus not included in hh_members"

/*income - dummies*/
*earned income 
 gen earn_inc_d_f = HH_226A__1_FEMALE
 label var earn_inc_d_f "Earned income Y/N, reported by female"
 label value earn_inc_d_f yesno

 gen earn_inc_d_m = HH_226A__1_MALE
 label var earn_inc_d_m "Earned income Y/N, reported by male"
 label value earn_inc_d_m yesno

*international remittances 
 gen intrem_inc_d_f = HH_226A__2_FEMALE
 label var intrem_inc_d_f "International remittances Y/N, reported by female"
 label value intrem_inc_d_f yesno

 gen intrem_inc_d_m = HH_226A__2_MALE
 label var intrem_inc_d_m "International remittances Y/N, reported by male"
 label value intrem_inc_d_m yesno

*domestic remittances
 gen domrem_inc_d_f = HH_226A__3_FEMALE
 label var domrem_inc_d_f "Domestic remittances Y/N, reported by female"
 label value domrem_inc_d_f yesno

 gen domrem_inc_d_m = HH_226A__3_MALE
 label var domrem_inc_d_m "Domestic remittances Y/N, reported by male"
 label value domrem_inc_d_m yesno

*other transfers 
 gen transf_inc_d_f = HH_226A__4_FEMALE
 label var transf_inc_d_f "Other transfers from family or friends Y/N, reported by female"
 label value transf_inc_d_f yesno

 gen transf_inc_d_m = HH_226A__4_MALE
 label var transf_inc_d_m "Other transfers from family or friends Y/N, reported by male"
 label value transf_inc_d_m yesno

*safety net 
 gen safety_inc_d_f = HH_226A__5_FEMALE
 label var safety_inc_d_f "Safety nets Y/N, reported by female"
 label value safety_inc_d_f yesno

 gen safety_inc_d_m = HH_226A__5_MALE
 label var safety_inc_d_m "Safety nets Y/N, reported by male"
 label value safety_inc_d_m yesno

*savings or selling assets 
 gen savass_inc_d_f = HH_226A__6_FEMALE
 label var savass_inc_d_f "Savings or selling assets Y/N, reported by female"
 label value savass_inc_d_f yesno

 gen savass_inc_d_m = HH_226A__6_MALE
 label var savass_inc_d_m "Savings or selling assets Y/N, reported by male"
 label value savass_inc_d_m yesno

*loan 
 gen loan_inc_d_f = HH_226A__7_FEMALE
 label var loan_inc_d_f "Loan Y/N, reported by female"
 label value loan_inc_d_f yesno
 
 gen loan_inc_d_m = HH_226A__7_MALE
 label var loan_inc_d_m "Loan Y/N, reported by male"
 label value loan_inc_d_m yesno

/*income - amounts*/
*earned income 
 gen earn_inc_f = HH_226B1_FEMALE
 label var earn_inc_f "Earned income amount, reported by female"
 
 gen earn_inc_m = HH_226B1_MALE
 label var earn_inc_m "Earned income amount, reported by male"

*international remittances 
 gen intrem_inc_f = HH_226B2_FEMALE
 label var intrem_inc_f "International remittances amount, reported by female"
 *hist intrem_inc_f			
 summ intrem_inc_f if ID!="W5348" 					//ID "W5348" recieves int. remit. in lump-sum, so exclude this obv. from analysis. 

 gen intrem_inc_m = HH_226B2_MALE
 label var intrem_inc_m "International remittances amount, reported by male"
 codebook intrem_inc_m

*domestic remittances
 gen domrem_inc_f = HH_226B3_FEMALE
 label var domrem_inc_f "Domestic remittances amount, reported by female"
 codebook domrem_inc_f

 gen domrem_inc_m = HH_226B3_MALE
 label var domrem_inc_m "Domestic remittances amount, reported by male"

*other transfers 
 gen transf_inc_f = HH_226B4_FEMALE
 label var transf_inc_f "Other transfers from family or friends amount, reported by female"

 gen transf_inc_m = HH_226B4_MALE
 label var transf_inc_m "Other transfers from family or friends amount, reported by male"
 
*safety net 
 gen safety_inc_f = HH_226B5_FEMALE
 label var safety_inc_f "Safety nets amount, reported by female"

 gen safety_inc_m = HH_226B5_MALE
 label var safety_inc_m "Safety nets amount, reported by male"

*savings or selling assets 
 gen savass_inc_f = HH_226B6_FEMALE
 label var savass_inc_f "Savings or selling assets amount, reported by female"
 
 gen savass_inc_m = HH_226B6_MALE
 label var savass_inc_m "Savings or selling assets amount, reported by male"
 
*loan
 gen loan_inc_f = HH_226B7_FEMALE
 label var loan_inc_f "Loan amount, reported by female"

 gen loan_inc_m = HH_226B7_MALE
 label var loan_inc_m "Loan amount, reported by male"
 
*total
 egen tot_inc_f = rowtotal(earn_inc_f intrem_inc_f domrem_inc_f transf_inc_f safety_inc_f savass_inc_f loan_inc_f)
 replace tot_inc_f = loan_inc_f if ID=="W5348"				//outlier migrant's wife only has loan in addition to int. rem. which we are excluding
 label var tot_inc_f "Total income of HH reported by female"

 egen tot_inc_m = rowtotal(earn_inc_m intrem_inc_m domrem_inc_m transf_inc_m safety_inc_m savass_inc_m loan_inc_m)
 label var tot_inc_m "Total income of HH reported by male"
 
 
/**** Labor variables ****/

/*work info from HH module*/
*work last 30 days 
 rename HH_211 work_30days

*work last 7 days 
 rename HH_212 work_7days

*paid work last 30 days 
 rename HH_213 paidwork_30days
 label var paidwork_30days "Paid work last 30 days, if work_30days == 1"

*paid work last 7 days 
 rename HH_214 paidwork_7days
 label var paidwork_7days "Paid work last 7 days, if work_7days == 1"

*ever work  
 rename HH_215 work_ever
 label var work_ever "Ever work, if work_30days == 0"

*ever paid work  
 rename HH_216 paidwork_ever
 label var paidwork_ever "Ever paid work, if work_ever == 1"

*paid work last job held
 rename HH_217 paidwork_lastjob
 label var paidwork_lastjob "Paid work last job held, if paidwork_ever == 1"
 
 
 foreach v of varlist work_30days work_7days paidwork_30days paidwork_7days work_ever paidwork_ever paidwork_lastjob {
	recode `v' (2=0)
	label val `v' yesno
	codebook `v'
 }

*current work status 
 rename HL6 current_work_status 
 label var current_work_status "Current working status of respondent"

*type of work - self 
 rename HH_218 work_type 
 label var work_type "Type of work in which respondent is/was engaged"
 
//following questions for respondents worked in past 30 days (N=1266, miss=734) or ever worked (N=166, miss=1834), totalN=1432, miss=568 
*description of work and NSCO, NSIC codes 
 recast str2045 L6, force
 replace L6 = trim(L6)
 rename L6 work_desc
 label var work_desc "Description of work in which respondent is/was engaged"

 rename L6_NSCO work_desc_NSCO 
 rename L6_NSIC work_desc_NSIC
 label var work_desc_NSCO "NSCO codes for work_desc"
 label var work_desc_NSIC "NSIC codes for work_desc"

*tag respodnents working in hotel/restaurant industry 
 gen work_hotel = 0 
 replace work_hotel = 1 if inlist(work_desc_NSCO, 1411, 1412, 5120, 5131, 5132)
 replace work_hotel = 1 if inlist(work_desc_NSIC, 5510, 5520, 5590, 5610, 5621, 5629, 5630)
 replace work_hotel = . if missing(work_desc_NSCO)
 label var work_hotel "Indicator for respodents working in the hotels or related occupations/sectors"

 gen work_hotel_fem = 0 
 replace work_hotel_fem = 1 if work_hotel==1 & gender==2
 replace work_hotel_fem = . if gender==1
 replace work_hotel_fem = . if missing(work_hotel)
 label var work_hotel_fem "Indicator for females working in the hotels or related occupations/sectors"

*aggregate codes
 recode work_desc_NSCO ///
	(110/310 = 1 "Armed forces occupations") ///
	(1111/1439 = 2 "Managers") ///
	(2111/2659 = 3 "Professionals") ///
	(3111/3522 = 4 "Technicians and associate professionals") ///
	(4110/4419 = 5 "Clerical support workers") ///
	(5111/5419 = 6 "Service and sales workers") ///
	(6111/6340 = 7 "Skilled agricultural, forestry and fishery workers") ///
	(7111/7549 = 8 "Craft and related trades workers") ///
	(8111/8350 = 9 "Plant and machine operators and assemblers") ///
	(9111/9629 = 10 "Elementary occupations") ///
 , gen(work_desc_NSCO_agg)
 label var work_desc_NSCO_agg "Aggregated NSCO codes for work_desc"

 recode work_desc_NSIC ///
	(111/322 = 1 "Agriculture, forestry and fishing") ///
	(510/990 = 2 "Mining and Quarrying") ///
	(1010/3320 = 3 "Manufacturing") ///
	(3510/3530 = 4 "Electricity, gas, steam and air conditioning supply") ///
	(3600/3900 = 5 "Water supply; sewerage, waste management and remediation activities") ///
	(4100/4390 = 6 "Construction") ///
	(4510/4799 = 7 "Wholesale and retail trade; repair of motor vehicles and motorcycles") ///
	(4911/5320 = 8 "Transportation and Storage") ///
	(5510/5630 = 9 "Accommodation and food services activities") ///
	(5811/6399 = 10 "Information and Communication") ///
	(6411/6630 = 11 "Financial and insurance activities") ///
	(6810/6820 = 12 "Real estate business activities") ///
	(6910/7500 = 13 "Prrofessional, scientific and technical activities") ///
	(7710/8299 = 14 "Administrative and Support Service Activities") ///
	(8411/8430 = 15 "Public administration and defense; compulsory social security") ///
	(8510/8550 = 16 "Education") ///
	(8610/8890 = 17 "Human health and social work activities") ///
	(9000/9329 = 18 "Arts, entertainment and recreation") ///
	(9411/9609 = 19 "Other service activities") ///
	(9700/9820 = 20 "Activities of households as employers; undifferentiated goods and services producing activities of households for own use") ///
	(9900 = 21 "Activities of Extra-territorial organizations and bodies)") ///
 , gen(work_desc_NSIC_agg)
 label var work_desc_NSIC_agg "Aggregated NSIC codes for work_desc"
 codebook work_desc_NSIC_agg, tab(100)
 
 recode work_desc_NSIC_agg (1 = 1 "Agri") (3/20 = 0 "Non-agri"), gen(work_agri)			        //Per ISIC4, "Agri" =="Agriculture; forestry and fishing"
 label var work_agri "Works in  Agriculture, forestry and fishing based on work_desc_NSIC_agg"
 
//following questions not asked if work_type == 1, 2, 4, so miss should be 568 + 506 = 1074
*sector	
 *tab ID L7_OS if L7 == 96	//2 says "NGO", and 1 is "semi-govt." which I am re-coding as Public 
 replace L7 = 1 if ID == "M5313"
 recode L7 (1 = 1 "Public") (2 = 2 "Private") (96 6 = 3 "Other (Cooperatives, Non-profits)"), gen(work_sector)
 label var work_sector "Sector of employer of current or last job, if not self-employed or in the army"
 replace work_sector = 1 if work_type == 4	//if in the army, tag as Public 
 replace work_sector = 4 if inlist(work_type, 1, 2)
 label define work_sector 4 "Self-employed (own account, employer)", add
 label val work_sector work_sector
 codebook work_sector

*share of females at workplace
 gen work_femaleper = L8 
 label var work_femaleper "Percentage of females at current workplace or at last job held"

*agreement type 
 rename L9 work_agreement 

*agreement duration  
 rename L10 work_agreement_dur

*SS contributions 
 rename L11 work_emp_ss
 label var work_emp_ss "Current or last employer contributing to social security on respondent's behalf"
 recode work_emp_ss (2=0)
 label val work_emp_ss yesno

*paid sick leave or compensation 
 rename L12 work_sickleave 
 label var work_sickleave "Paid sick leave or compensation in case of illness or injury"
 recode work_sickleave (2=0)
 label val work_sickleave yesno

//back to currenly working or ever worked, so miss should be 568
*duration of work
 gen work_duration = L1
 label var work_duration "Number of months working in current job" 
 recode work_duration (1/11 = 1 "less then 1") (12/59 = 2 "1 to less than 5") (60/119 = 3 "5 to less than 10") (120/442 = 4 "10 or more"), gen(work_duration_cat) 
 label var work_duration_cat "Categories of number of years working in current job"
 
*location
 rename L2 work_location 
 label var work_location "Location of current or last job held"
 
 recode work_location (1 = 1 "Home or structure attached to home") (2/4 = 0 "Outside or both"), gen(work_inside)
 label var work_inside "Dummy for working at home or structure attached to home"

*mode of travel
//also not asked if work_location == 1, so #missing will be 568 + 397 = 965
 rename L3 work_travelmode
 replace work_travelmode = . if work_travelmode == 99		//2 respondents in the army
 label var work_travelmode "Mode of travel to current or last job held"

*reason for travel mode
 replace L4__96 = 0 if inlist(ID,"W5720","W5853","W6057")
 replace L4__96 = 0 if ID == "M5106"			 //blank specifics so recode LS__96 as 0
 replace L4__4 = 1 if inlist(ID, "M5108", "W5139", "W5211")  //"Pataho Rider" is a ride-hailing app, "My workplace is nearby" -- recode as convenient

 gen work_travelmode_safe = L4__1
 label var work_travelmode_safe "Feel safe using it"

 gen work_travelmode_avail = L4__2
 label var work_travelmode_avail "Only available option"

 gen work_travelmode_fampref = L4__3
 label var work_travelmode_fampref "Family prefers I use this"

 gen work_travelmode_conv = L4__4 
 label var work_travelmode_conv "Convenient access" 

 gen work_travelmode_afford = L4__5
 label var work_travelmode_afford "Affordable"

 label val work_travelmode_* yesno
 
*time for commute to work 
 gen work_commute_time = L5 
 label var work_commute_time "One way commute to current or last job held, in mins"

*job serach method 			
 replace L13 = 6 if L13==96		//all 6 as "other" refer to ward office or local municipality, so recode to "government office"
 label define L13 6 "Government office", add 
 label val L13 L13
 rename L13 work_search_method
 label var work_search_method "Method used to find current or last job held"

*job search duration 
 gen work_search_dur = L14 
 label var work_search_dur "Number of weeks to find current or last job held"
 recode work_search_dur (1 = 1 "1 week") (2 = 2 "2 weeks") (3 = 3 "3 weeks") (4 = 4 "1 month") (5/8 = 5 "2 months") (9/13 = 6 "3 months") (14/17 = 7 "4 months") (18/21 = 8 "5 months") (22/26 = 9 "6 months") (27/51 = 10 ">6 months but less than 1 yr") (51/208 = 11 ">1 yr"), gen(work_search_dur_cat)
 label var work_search_dur_cat "Categories of time taken to find current or last job held"

*weekly work hours 
 gen double work_hours_weekly = L15 
 label var work_hours_weekly "Number of hours of work in typical week for current or last job held"
 *summ work_hours_weekly, detail
 *hist work_hours_weekly
 winsor2 work_hours_weekly, replace cuts(0 95)			//replace extreme value (105) with 95th percentile 


//gross monthly income, asked if paid work only (codebook paidwork_30days paidwork_lastjob), thus miss = 588
*type of income 
 gen work_inc_type = 1
 replace work_inc_type = 2 if L16 == 0
 replace work_inc_type = . if missing(L16)
 label define work_inc_type 1 "paid in cash" 2 "paid in kind"
 label val work_inc_type work_inc_type
 label var work_inc_type "Income in last 30 days or monthly from last job earned in cash or kind"

*amount 
 gen work_inc_amt = L16 
 replace work_inc_amt = . if missing(work_inc_type) | work_inc_type == 2
 label var work_inc_amt "Gross income in last 30 days or monthly from last job, NPR (if paid in cash)"
 *summ work_inc_amt		//Note that 18 respondents paid in kind are not included here

//income change 
 gen double work_inc_chng = . 
 replace work_inc_chng = 1 if L17==1 | L18==1
 replace work_inc_chng = 2 if L17==2 | L18==2
 replace work_inc_chng = 3 if L17==3 | L18==3
 replace work_inc_chng = 4 if L17==4 | L18==4
 replace work_inc_chng = 5 if L17==5
 label define work_inc_chng 1 "Remained the same" 2 "Increased" 3 "Decreased" 4 "Increased and decreased" 5 "Started work this or last month" 
 label val work_inc_chng work_inc_chng 
 label var work_inc_chng "Monthly income change during current or last job, NPR (if paid in cash)"

*anticipated time in current job 
 rename L19 work_dur_exp 
 label var work_dur_exp "Anticipated months in current job"
 recode work_dur_exp (1/11 = 1 "less then 1") (12/59 = 2 "1 to less than 5") (60/94 96/119 = 3 "5 to less than 10") (120/351 = 4 "10 to less than 30") (95 = 5 "As long as I/employer wants"), gen(work_dur_exp_cat)
 label var work_dur_exp_cat "Categories of anticipated years in current job"

*childcare options 
 rename L20__1_FEMALE chcare_inlaws_f
 rename L20__2_FEMALE chcare_spouse_f
 rename L20__3_FEMALE chcare_sib_f
 rename L20__4_FEMALE chcare_fam_f
 rename L20__5_FEMALE chcare_workp_f
 rename L20__6_FEMALE chcare_worknp_f
 rename L20__7_FEMALE chcare_center_f
 rename L20__8_FEMALE chcare_neig_f
 rename L20__9_FEMALE chcare_babysit_f
 gen double chcare_na_f = 0 
 replace chcare_na_f = 1 if L20__98_FEMALE == 1 | L20__99_FEMALE == 1 
 replace chcare_na_f = . if missing(L20__98_FEMALE)
 label var chcare_na_f "Chilcare - child not young/no child"

 rename L20__1_MALE chcare_spouse_m
 rename L20__2_MALE chcare_parents_m
 rename L20__3_MALE chcare_sib_m
 rename L20__4_MALE chcare_fam_m
 rename L20__5_MALE chcare_workp_m
 rename L20__6_MALE chcare_workpw_m
 rename L20__7_MALE chcare_worknp_m
 rename L20__8_MALE chcare_worknpw_m
 rename L20__9_MALE chcare_center_m
 rename L20__10_MALE chcare_neig_m
 rename L20__11_MALE chcare_babysit_m
 gen double chcare_na_m = 0 
 replace chcare_na_m = 1 if L20__98_MALE == 1 | L20__99_MALE == 1 
 replace chcare_na_m = . if missing(L20__98_MALE)
 label var chcare_na_m "Chilcare - child not young/no child"

 foreach var in chcare_* {
	label val `var' yesno
 }

*chilcare reasons for family options only  
 rename L21__1 chcare_r_noop
 rename L21__2 chcare_r_trust
 rename L21__3 chcare_r_pay
 rename L21__4 chcare_r_qual
 label var chcare_r_noop "Reason no non-fam option chcare: none available"
 label var chcare_r_trust "Reason no non-fam option chcare: no trust"
 label var chcare_r_pay "Reason no non-fam option chcare: not willing to pay"
 label var chcare_r_qual "Reason no non-fam option chcare: poor perceived quality"

 foreach var in chcare_r_* {
	label val `var' yesno
 }

*hh chores when away for work 
 rename L22__1 chores_help_moth
 rename L22__2 chores_help_fath
 rename L22__3 chores_help_spouse
 rename L22__4 chores_help_sis
 rename L22__5 chores_help_hire
 rename L22__6 chores_help_son
 rename L22__7 chores_help_dghter
 rename L22__8 chores_help_none

//recoding other_specify 
 replace chores_help_moth = 1 if inlist(ID,"W5060","W5075","W5108","W5172","W5184","W5205","W5339","W5349")
 replace chores_help_moth = 1 if inlist(ID,"W5390","W5675","W5708","W5780")
 replace chores_help_fath = 1 if inlist(ID,"W5060","W5172","W5184","W5708","W5780")
 replace chores_help_sis = 1 if inlist(ID,"W5060","W5076","M5096","M5138","W5172","W5205","W5507","W5675")
 replace chores_help_sis = 1 if inlist(ID,"W5708","M5946","W6155","M6160")
 replace chores_help_dghter = 1 if inlist(ID,"M5288","W5288","W5739")
 gen chores_help_bro = 0 
 replace chores_help_bro = 1 if inlist(ID,"W5780","W6275")
 replace chores_help_bro = . if missing(L22__96)
 label var chores_help_bro "Help w/ HH chores when working: brother"

 gen chores_help_othf = 0 
 replace chores_help_othf = 1 if inlist(ID,"W5195","W5315")
 replace chores_help_othf = . if missing(L22__96)
 label var chores_help_othf "Help w/ HH chores when working: other females" 		//includes neice, grandmother

 label var chores_help_moth "Help w/ HH chores when working: MIL or mother"
 label var chores_help_fath "Help w/ HH chores when working: FIL or father"
 label var chores_help_spouse "Help w/ HH chores when working: spouse"
 label var chores_help_sis "Help w/ HH chores when working: SIL or sister"
 label var chores_help_hire "Help w/ HH chores when working: hired help"
 label var chores_help_son "Help w/ HH chores when working: son"
 label var chores_help_dghter "Help w/ HH chores when working: DIL or daughter"
 label var chores_help_none "Help w/ HH chores when working: no one but self"

 foreach var in chores_help* {
	label val `var' yesno
 }

*job search dur expected - currently working (miss should be 1834)
 gen work_search_dur_exp = L23
 label var work_search_dur_exp "Estimated time to find job for work_ever==1, in weeks"
 tab work_search_dur_exp

 recode work_search_dur_exp (1 = 1 "1 week") (2 = 2 "2 weeks") (3 = 3 "3 weeks") (4 = 4 "1 month") (5/8 = 5 "2 months") (9/60 = 6 ">2 months"), gen(work_search_dur_exp_cat)
 label var work_search_dur_exp_cat "Categories of estimated time to find job for work_ever==1"
 
//following questions for work_30days==2, so miss should be 1266
*job search dur expected 
 gen work_search_dur_exp2 = L24
 label var work_search_dur_exp2 "Estimated time to find job for work_30days==no, in weeks"
 tab work_search_dur_exp2
 recode work_search_dur_exp2 (1 = 1 "1 week") (2 = 2 "2 weeks") (3 = 3 "3 weeks") (4 = 4 "1 month") (5/8 = 5 "2 months") (9/13 = 6 "3 months") (14/17 = 7 "4 months") (18/21 = 8 "5 months") (22/26 = 9 "6 months") (27/51 = 10 ">6 months but less than 1 yr") (51/210 = 11 ">1 yr"), gen(work_search_dur_exp2_cat)
 label var work_search_dur_exp2_cat "Categories of estimated time to find job for work_30days==no"

*reason for currently not working 
 rename L25__1 r_nowork_des
 rename L25__2 r_nowork_old
 rename L25__3 r_nowork_ill
 rename L25__5 r_nowork_educ
 rename L25__6 r_nowork_chil
 rename L25__7 r_nowork_eld
 rename L25__8 r_nowork_chore
 rename L25__9 r_nowork_supp
 rename L25__10 r_nowork_avail
 rename L25__11 r_nowork_fin

 replace r_nowork_educ = 1 if inlist(ID,"M5951")		
 replace r_nowork_chil = 1 if inlist(ID,"W6049")															//"pregnant"
 replace r_nowork_avail = 1 if inlist(ID,"M5007","W5684","M5760","M5898","W5001","W5025","M5865","M6035") 	//"employers do not pay timely","no profit from business","workplace shut down", "off-season"

 gen r_nowork_mig = 0 
 replace r_nowork_mig = 1 if inlist(ID,"M5787","W5924")
 replace r_nowork_mig = . if missing(L25__96)
 label var r_nowork_mig "Want to migrate abroad for work"
 label var r_nowork_des "No desire to work"
 label var r_nowork_old "Retired or too old"
 label var r_nowork_ill "Illness, injury or disability (long-term or temp)"
 label var r_nowork_educ "Currently (or start soon) studying or upgrading qual"
 label var r_nowork_chil "Childcare, no other options I trust"
 label var r_nowork_eld "Eldercare"
 label var r_nowork_chore "HH chores, no one to take over"
 label var r_nowork_supp "No support from family"
 label var r_nowork_avail "No suitable jobs available"
 label var r_nowork_fin "No financial need"

 foreach var in r_nowork_* {
	label val `var' yesno
 }
 
 gen r_nowork_other = r_nowork_des + r_nowork_old + r_nowork_fin + r_nowork_mig + r_nowork_educ
 label var r_nowork_other "Other reasons"
 label val r_nowork_other yesno

*take job in city/village
 rename L26 jobopp_incity
 label var jobopp_incity "Take job if available in city/village"
 recode jobopp_incity (2=0)
 label val jobopp_incity yesno

*take job outside city/village
 rename L27 jobopp_outcity
 label var jobopp_outcity "Take job if available outside city/village but in NPL"
 recode jobopp_outcity (2=0)
 label val jobopp_outcity yesno

*min salary exp 
 gen jobopp_minsal = L28 
 label var jobopp_minsal "If willing to take up job, least salary expected per month (NPR)"
 *summ jobopp_minsal, detail
 *hist jobopp_minsal
 winsor2 jobopp_minsal, replace cuts(0 99)		//2 observtions with extremes (80000), replace with 99th percentile 
 
//following for work_30days==no and work_ever==1

*year of stopping work 			  
 tostring L29_AD, gen(year_stopwork)
 label var year_stopwork "Year of stopping work, if not currently working but worked earlier"

*years since stopping work, as of 2023 
 gen yearsince2023_stopwork = 2023 - L29_AD
 replace yearsince2023_stopwork = . if missing(L29_AD)
 label var yearsince2023_stopwork "Number of years as of 2023 since respondent stopped working, if not currently working but worked earlier"

*reason for stopping work 
 rename L30__1 r_quitwork_fire
 rename L30__2 r_quitwork_marr
 rename L30__3 r_quitwork_chil
 rename L30__4 r_quitwork_old
 rename L30__5 r_quitwork_ill
 rename L30__6 r_quitwork_educ
 rename L30__7 r_quitwork_chore
 rename L30__8 r_quitwork_care
 rename L30__9 r_quitwork_supp
 rename L30__10 r_quitwork_des
 
 replace r_quitwork_fire = 1 if inlist(ID,"M5067","M5077","W5077","W5339","W5684")	//includes "workplace shut down"
 gen r_quitwork_avail = 0 
 replace r_quitwork_avail = 1 if inlist(ID,"M5007","W5012","W5025","W5099","M5214")
 replace r_quitwork_avail = 1 if inlist(ID,"M5291","W5291","W5420","W5463","W5495")
 replace r_quitwork_avail = 1 if inlist(ID,"W5519","W5559","W5568","M5640","W5735")
 replace r_quitwork_avail = 1 if inlist(ID,"M5760","M5841","M5865","M5898","M6035","W6249","W6491","M6758","M6789")
 replace r_quitwork_avail = . if missing(L30__96)
 label var r_quitwork_avail "Could not find suitable job" //includes "hired for limited time", "off-season", "pandemic", "not enough profit", "salary too low/not paid"

 gen r_quitwork_mig = 0 
 replace r_quitwork_mig = 1 if inlist(ID,"M5787")
 replace r_quitwork_mig = . if missing(L30__96)
 label var r_quitwork_mig "Wanted to migrate abroad for work"


 label var r_quitwork_fire "Laid off/fired"
 label var r_quitwork_marr "Got married"
 label var r_quitwork_chil "Had child(ren)"
 label var r_quitwork_old "Retired or too old"
 label var r_quitwork_ill "Illness, injury or disability (long-term or temp)"
 label var r_quitwork_educ "Studying or upgrading qual"
 label var r_quitwork_chore "Juggling HH chores and work was too much"
 label var r_quitwork_care "Juggling care and work was too much"
 label var r_quitwork_supp "No support from family"
 label var r_quitwork_des "No desire to work"

 foreach var in r_quitwork_* {
	label val `var' yesno
 }

//following are for employers, thus miss should be 1991
*number of full-time employees
 rename L31 employees_ft_num
 label var employees_ft_num "Number of full-time employees (ex. self), if employer"

*number of part-time employees
 rename L32 employees_pt_num
 label var employees_pt_num "Number of part-time employees (ex. self), if employer"

*percentage of female employees
 rename L33 employees_f_per
 label var employees_f_per "Percentage of female employees, if employer"

//following for self-employed, thus miss should be 1499
*main enabling factors that helped you start business
 rename L34__1 entrp_enab_capital
 rename L34__2 entrp_enab_loan
 rename L34__3 entrp_enab_training
 rename L34__4 entrp_enab_famsupp
 rename L34__5 entrp_enab_chcare
 rename L34__6 entrp_enab_elcare
 rename L34__7 entrp_enab_chore
 rename L34__8 entrp_enab_aspire
 rename L34__9 entrp_enab_avail

 label var entrp_enab_capital "Start-up capital from family/friends/savings"
 label var entrp_enab_loan "Start-up capital/operation costs from loan"
 label var entrp_enab_training "Apt training - entrepreneurship & comms skills"
 label var entrp_enab_famsupp "Family supported/encouraged"
 label var entrp_enab_chcare "Had options for childcare"
 label var entrp_enab_elcare "Eldercare not sole responsibility"
 label var entrp_enab_chore "Help with HH chores"
 label var entrp_enab_aspire "Aspiration to be an entrepreneur"
 label var entrp_enab_avail "Need due to suitable jobs not available"

 replace entrp_enab_famsupp = 1 if L34__96 == 1

 foreach var in entrp_enab_* {
	label val `var' yesno
 }

*desired support from the govt to do your business well		
 rename L35 entrp_govsupp_des 
 recast str2045 entrp_govsupp_des, force
 label var entrp_govsupp_des "Desired support from govt. for business, if employer" 	
 
 encode entrp_govsupp_des, gen(entrp_govsupp_des_num)
 recode entrp_govsupp_des_num ///
	(3 12 13 16/20 25 31 38 40/47 49/53 55/57 60 61 75 96 97 99 101 106 109 112 126/132 135 136 140 141 143/145 148/155 165 166/170 173 177/193 201 205/214 217 220 = 1 "Grants, concessional loans, fin. assistance") ///
	(85/88 91 103 105 111 113 114 = 2 "Macro factors inc. reduction of inflation, rent, gas prices") ///
	(5/11 14 15 22 24 34 36 90 93 95 98 102 104 117 119/124 137/139 142 147 164 166 171 198 = 3 "Better business env. inc. simple procedures, logistics, market access/SEZs") ///
	(4 89 92 100 107 108 110 115 116 118 146 163 218 = 4 "Tax breaks") ///
	(32 35 37 39 54 63 64 174 175 194 197 202/204 215 = 5 "Non-fin assitance such as subsidized equipment, supplies") ///
	(21 26/30 33 48 58 59 62 65/74 76/84 94 172 176 195 196 199 200 216 219 222 = 6 "Provision of training, relevant job support") ///
	(2 23 125 133 134 156/162 221 = 7 "No expectations from govt. (inc. no response)") ///
 , gen(entrp_govsupp_des_cat)
 replace entrp_govsupp_des_cat = 7 if missing(entrp_govsupp_des_num)
 replace entrp_govsupp_des_cat = . if entrp_govsupp_des_num == 1
 label var entrp_govsupp_des_cat "Categories for desired support from govt. for business, if employer"

//following for work_30days==no or non-self-employed
 rename L36 entrp_des 
 label var entrp_des "Desire to start business, if not self-employed or work_30days==no"
 recode entrp_des (2=0)
 label val entrp_des yesno

*sector/activity for business
 rename L37 entrp_des_activity 
 label var entrp_des_activity "Activity, sector of desired business, if not self-employed or work_30days==no"

 rename L37_NSCO entrp_des_activity_NSCO 
 rename L37_NSIC entrp_des_activity_NSIC
 label var entrp_des_activity_NSCO "NSCO codes for entrp_des_activity"
 label var entrp_des_activity_NSIC "NSIC codes for entrp_des_activity"
*aggregate codes
 recode entrp_des_activity_NSCO ///
	(110/310 = 1 "Armed forces occupations") ///
	(1111/1439 = 2 "Managers") ///
	(2111/2659 = 3 "Professionals") ///
	(3111/3522 = 4 "Technicians and associate professionals") ///
	(4110/4419 = 5 "Clerical support workers") ///
	(5111/5419 = 6 "Service and sales workers") ///
	(6111/6340 = 7 "Skilled agricultural, forestry and fishery workers") ///
	(7111/7549 = 8 "Craft and related trades workers") ///
	(8111/8350 = 9 "Plant and machine operators and assemblers") ///
	(9111/9629 = 10 "Elementary occupations") ///
 , gen(entrp_des_activity_NSCO_agg)
 label var entrp_des_activity_NSCO_agg "Aggregated NSCO codes for entrp_des_activity"

 recode entrp_des_activity_NSIC ///
	(111/322 = 1 "Agriculture, forestry and fishing") ///
	(510/990 = 2 "Mining and Quarrying") ///
	(1010/3320 = 3 "Manufacturing") ///
	(3510/3530 = 4 "Electricity, gas, steam and air conditioning supply") ///
	(3600/3900 = 5 "Water supply; sewerage, waste management and remediation activities") ///
	(4100/4390 = 6 "Construction") ///
	(4510/4799 = 7 "Wholesale and retail trade; repair of motor vehicles and motorcycles") ///
	(4911/5320 = 8 "Transportation and Storage") ///
	(5510/5630 = 9 "Accommodation and food services activities") ///
	(5811/6399 = 10 "Information and Communication") ///
	(6411/6630 = 11 "Financial and insurance activities") ///
	(6810/6820 = 12 "Real estate business activities") ///
	(6910/7500 = 13 "Prrofessional, scientific and technical activities") ///
	(7710/8299 = 14 "Administrative and Support Service Activities") ///
	(8411/8430 = 15 "Public administration and defense; compulsory social security") ///
	(8510/8550 = 16 "Education") ///
	(8610/8890 = 17 "Human health and social work activities") ///
	(9000/9329 = 18 "Arts, entertainment and recreation") ///
	(9411/9609 = 19 "Other service activities") ///
	(9700/9820 = 20 "Activities of households as employers; undifferentiated goods and services producing activities of households for own use") ///
	(9900 = 21 "Activities of Extra-territorial organizations and bodies)") ///
 , gen(entrp_des_activity_NSIC_agg)
 label var entrp_des_activity_NSIC_agg "Aggregated NSIC codes for work_desc"
 
*anticipaited main barriers to start desired business
 rename L38__1 entrp_des_barr_capital 
 rename L38__2 entrp_des_barr_skill
 rename L38__3 entrp_des_barr_famsupp 
 rename L38__4 entrp_des_barr_chcare 
 rename L38__5 entrp_des_barr_elcare 
 rename L38__6 entrp_des_barr_chore 

 label var entrp_des_barr_capital "Start-up capital not easily available"
 label var entrp_des_barr_skill "Lack necessary entrepreneurship skills"
 label var entrp_des_barr_famsupp "Lack family support"
 label var entrp_des_barr_chcare "Majorly responsible for childcare"
 label var entrp_des_barr_elcare "Majorly responsible for eldercare"
 label var entrp_des_barr_chore "No help with HH chores"

 replace entrp_des_barr_capital = 1 if inlist(ID,"W5019","W5242","W5307","W6045")	//includes lack of apt location, land, irrigation facilities 
 replace entrp_des_barr_skill = 1 if inlist(ID,"M5126","W5174","W5361","M5767") 		//inclues lack of knowledge to identify market, start despite disability 

 foreach var in entrp_des_barr_* {
	label val `var' yesno
 }


//following for all respondents 
*paid jobs avaiable for women in city/village 
 recast str2045 L39, force
 replace L39 = trim(L39)		
 rename L39 paidjob_f_avail
 label var paidjob_f_avail "Paid jobs available for women in city/village"

 forvalues i = 1/5 {
 rename L39_NSCO_`i' paidjob_f_avail_NSCO`i' 
 label var paidjob_f_avail_NSCO`i' "NSCO codes for paidjob_f_avail" 	
 }

 forvalues i = 1/5 {
 rename L39_NSIC_`i' paidjob_f_avail_NSIC`i' 
 label var paidjob_f_avail_NSIC`i' "NSIC codes for paidjob_f_avail" 	
 }

*aggregate codes
 forvalues i = 1/5 {
  recode paidjob_f_avail_NSCO`i' ///
	(110/310 = 1 "Armed forces occupations") ///
	(1111/1439 = 2 "Managers") ///
	(2111/2659 = 3 "Professionals") ///
	(3111/3522 = 4 "Technicians and associate professionals") ///
	(4110/4419 = 5 "Clerical support workers") ///
	(5111/5419 = 6 "Service and sales workers") ///
	(6111/6340 = 7 "Skilled agricultural, forestry and fishery workers") ///
	(7111/7549 = 8 "Craft and related trades workers") ///
	(8111/8350 = 9 "Plant and machine operators and assemblers") ///
	(9111/9629 = 10 "Elementary occupations") ///
 , gen(paidjob_f_avail_NSCO`i'_agg)
 label var paidjob_f_avail_NSCO`i'_agg "Aggregated NSCO codes for work_desc"
 }

 forvalues i = 1/5 {
  recode paidjob_f_avail_NSIC`i' ///
	(111/322 = 1 "Agriculture, forestry and fishing") ///
	(510/990 = 2 "Mining and Quarrying") ///
	(1010/3320 = 3 "Manufacturing") ///
	(3510/3530 = 4 "Electricity, gas, steam and air conditioning supply") ///
	(3600/3900 = 5 "Water supply; sewerage, waste management and remediation activities") ///
	(4100/4390 = 6 "Construction") ///
	(4510/4799 = 7 "Wholesale and retail trade; repair of motor vehicles and motorcycles") ///
	(4911/5320 = 8 "Transportation and Storage") ///
	(5510/5630 = 9 "Accommodation and food services activities") ///
	(5811/6399 = 10 "Information and Communication") ///
	(6411/6630 = 11 "Financial and insurance activities") ///
	(6810/6820 = 12 "Real estate business activities") ///
	(6910/7500 = 13 "Prrofessional, scientific and technical activities") ///
	(7710/8299 = 14 "Administrative and Support Service Activities") ///
	(8411/8430 = 15 "Public administration and defense; compulsory social security") ///
	(8510/8550 = 16 "Education") ///
	(8610/8890 = 17 "Human health and social work activities") ///
	(9000/9329 = 18 "Arts, entertainment and recreation") ///
	(9411/9609 = 19 "Other service activities") ///
	(9700/9820 = 20 "Activities of households as employers; undifferentiated goods and services producing activities of households for own use") ///
	(9900 = 21 "Activities of Extra-territorial organizations and bodies)") ///
 , gen(paidjob_f_avail_NSIC`i'_agg)
 label var paidjob_f_avail_NSIC`i'_agg "Aggregated NSIC codes for work_desc"
 }

*resources available to a person with your profile to try to find work in the city/village
 rename L40__1 job_srch_res_network
 rename L40__2 job_srch_res_online
 rename L40__3 job_srch_res_agent
 rename L40__4 job_srch_res_fambus
 rename L40__5 job_srch_res_news
 rename L40__6 job_srch_res_govt

 label var job_srch_res_network "Friends, teachers, family, other networks"
 label var job_srch_res_online "Social media or websites such as job portals "
 label var job_srch_res_agent "Job agencies/employment office"
 label var job_srch_res_fambus "Own or family business"
 label var job_srch_res_news "Newspaper"
 label var job_srch_res_govt "ESCs MoLESS or other govt. office"

 replace job_srch_res_govt = 1 if L40__96==1

 foreach var in job_srch_res_* {
	label val `var' yesno
 }

*names of job portals 
 rename L41__0 job_srch_portal
 split job_srch_portal, p(", " ". " ".  ") gen(job_srch_portal)

 forvalues i = 1/4 {
	replace job_srch_portal`i' = "" if job_srch_portal`i' == "99" 
 }

 forvalues i = 1/4 {
	encode job_srch_portal`i', gen(job_srch_portal`i'_num) 
 }

 replace job_srch_portal1_num = 6 if job_srch_portal1_num == 7
 label define job_srch_portal1_num 5 "hamrojobs.com", modify 
 label define job_srch_portal1_num 16 "Twitter", add 
 label values job_srch_portal1_num job_srch_portal1_num

 replace job_srch_portal2_num  = 1 if inlist(job_srch_portal2_num,1, 3)
 replace job_srch_portal2_num  = 6 if inlist(job_srch_portal2_num,4)
 replace job_srch_portal2_num  = 8 if inlist(job_srch_portal2_num,5)
 replace job_srch_portal2_num  = 11 if inlist(job_srch_portal2_num,6)
 replace job_srch_portal2_num  = 13 if inlist(job_srch_portal2_num,7)
 replace job_srch_portal2_num  = 16 if inlist(job_srch_portal2_num,2)
 replace job_srch_portal2_num  = 14 if inlist(job_srch_portal2_num,8)
 label value job_srch_portal2_num job_srch_portal1_num

 replace job_srch_portal3_num  = 6 if inlist(job_srch_portal3_num,2)
 replace job_srch_portal3_num  = 11 if inlist(job_srch_portal3_num,3)
 label value job_srch_portal3_num job_srch_portal1_num

 replace job_srch_portal4_num  = 16 if inlist(job_srch_portal4_num,1)
 label value job_srch_portal4_num job_srch_portal1_num
 drop job_srch_portal job_srch_portal1 job_srch_portal2 job_srch_portal3 job_srch_portal4

 forvalues i = 1/4 {
	rename job_srch_portal`i'_num job_srch_portal`i' 
 }

 forvalues i = 1/4 {
	label var job_srch_portal`i' "Job portals of websites respodent is aware of" 
 }

*childcare options are available for working women in your city/village
 rename L42__1 chcare_avail_inlaws
 rename L42__2 chcare_avail_sib
 rename L42__3 chcare_avail_fam
 rename L42__4 chcare_avail_workp
 rename L42__5 chcare_avail_center
 rename L42__6 chcare_avail_neig
 rename L42__7 chcare_avail_babysit

 foreach v of varlist chcare_avail_inlaws chcare_avail_sib chcare_avail_fam chcare_avail_workp chcare_avail_center chcare_avail_neig chcare_avail_babysit {
	label val `v' yesno
 }

	
/**** Vignette variables ****/
 rename (V11 V12 V13) (v_mig_city v_mig_abroad v_mig_base)
 rename (V21 V22 V23 V24) (v_work_ll v_work_lh v_work_hl v_work_hh)

*migration
 gen v_mig_bc = .
 replace v_mig_bc = 1 if v_mig_base == 1 & v_mig_city == 1
 replace v_mig_bc = 2 if v_mig_base == 1 & v_mig_city == 2
 replace v_mig_bc = 3 if v_mig_base == 2 & v_mig_city == 2
 replace v_mig_bc = 4 if v_mig_base == 2 & v_mig_city == 1
 label var v_mig_bc "migratnion vignette city compared to base scenario"
 label define v_mig_bc 1 "base yes city yes" 2 "base yes city no" 3 "base no city no" 4 "base no city yes"
 label value v_mig_bc v_mig_bc

 gen v_mig_ba = .
 replace v_mig_ba = 1 if v_mig_base == 1 & v_mig_abroad == 1
 replace v_mig_ba = 2 if v_mig_base == 1 & v_mig_abroad == 2
 replace v_mig_ba = 3 if v_mig_base == 2 & v_mig_abroad == 2
 replace v_mig_ba = 4 if v_mig_base == 2 & v_mig_abroad == 1
 label var v_mig_ba "migratnion vignette abroad compared to base scenario"
 label define v_mig_ba 1 "base yes abroad yes" 2 "base yes abroad no" 3 "base no abroad no" 4 "base no abroad yes"
 label value v_mig_ba v_mig_ba

 
/**** Reference group variables ****/
*Life events 
 forvalues i = 1/5 {
	replace RA2_`i'=0 if RA2_`i'==2
	label val RA2_`i' yesno
 } 

 clonevar rgextent_le_spouse = RA3_1 
 clonevar rgextent_le_hhfam = RA3_2 
 clonevar rgextent_le_othfam = RA3_3 
 clonevar rgextent_le_comm = RA3_4 
 clonevar rgextent_le_othfam_fam = RA4_3 
 clonevar rgextent_le_comm_fam = RA4_4

 foreach v in RA3_1 RA3_2 RA3_3 RA3_4 RA4_3 RA4_4 {
	gen bin`v'=(`v'==4)
 }
 rename RA2_1 le_o_spouse 
 rename RA3_1 le_oe_spouse
 rename binRA3_1 le_om_spouse

 rename RA2_2 le_o_hhfam 
 rename RA3_2 le_oe_hhfam 
 rename binRA3_2 le_om_hhfam

 rename RA2_3 le_o_othfam
 rename RA3_3 le_oe_othfam
 rename binRA3_3 le_om_othfam
 rename RA4_3 le_oef_othfam
 rename binRA4_3 le_omf_othfam

 rename RA2_4 le_o_comm
 rename RA3_4 le_oe_comm
 rename binRA3_4 le_om_comm
 rename RA4_4 le_oef_comm
 rename binRA4_4 le_omf_comm

 label var le_o_spouse "Spouse has opinion - Life events"
 label var le_oe_spouse "Spouse opinion extent - Life events"
 label var le_om_spouse "Spouse's opinion matters - Life events"

 label var le_o_hhfam "Other HH members have opinion - Life events"
 label var le_oe_hhfam "Other HH members opinion extent - Life events"
 label var le_om_hhfam "Other HH members' opinion matters - Life events"

 label var le_o_othfam "Non-HH family has opinion - Life events"
 label var le_oe_othfam "Non-HH family opinion extent - Life events"
 label var le_om_othfam "Non-HH family's opinion matters - Life events"
 label var le_oef_othfam "Non-HH family's opinion extent to fam - Life events"
 label var le_omf_othfam "Non-HH family's opinion matters to fam - Life events"

 label var le_o_comm "Community has opinion - Life events"
 label var le_oe_comm "Community opinion extent - Life events"
 label var le_om_comm "Community opinion matter - Life events"
 label var le_oef_comm "Community opinion extent  to family - Life events"
 label var le_omf_comm "Community opinion matter to family - Life events"

*work outside for pay 
 forvalues i = 1/5 {
	replace RB2_`i'=0 if RB2_`i'==2
	label val RB2_`i' yesno
 } 

 clonevar rgextent_pw_spouse = RB3_1  
 clonevar rgextent_pw_hhfam = RB3_2  
 clonevar rgextent_pw_othfam = RB3_3  
 clonevar rgextent_pw_comm = RB3_4  
 clonevar rgextent_pw_othfam_fam = RB4_3 
 clonevar rgextent_pw_comm_fam = RB4_4

 foreach v in RB3_1 RB3_2 RB3_3 RB3_4 RB4_3 RB4_4 {
	gen bin`v'=(`v'==4)
 }

 rename RB2_1 pw_o_spouse 
 rename RB3_1 pw_oe_spouse
 rename binRB3_1 pw_om_spouse

 rename RB2_2 pw_o_hhfam 
 rename RB3_2 pw_oe_hhfam
 rename binRB3_2 pw_om_hhfam

 rename RB2_3 pw_o_othfam
 rename RB3_3 pw_oe_othfam
 rename binRB3_3 pw_om_othfam
 rename RB4_3 pw_oef_othfam
 rename binRB4_3 pw_omf_othfam

 rename RB2_4 pw_o_comm
 rename RB3_4 pw_oe_comm
 rename binRB3_4 pw_om_comm
 rename RB4_4 pw_oef_comm
 rename binRB4_4 pw_omf_comm

 label var pw_o_spouse "Spouse has opinion - paid work outside"
 label var pw_oe_spouse "Spouse's opinion extent - paid work outside"
 label var pw_om_spouse "Spouse's opinion matters - paid work outside"

 label var pw_o_hhfam "Other HH members have opinion - paid work outside"
 label var pw_oe_hhfam "Other HH members' opinion extent - paid work outside"
 label var pw_om_hhfam "Other HH members' opinion matters - paid work outside"

 label var pw_o_othfam "Non-HH family has opinion - paid work outside"
 label var pw_oe_othfam "Non-HH family's opinion extent - paid work outside"
 label var pw_om_othfam "Non-HH family's opinion matters - paid work outside"
 label var pw_oef_othfam "Non-HH family's opinion extent to fam - paid work outside"
 label var pw_omf_othfam "Non-HH family's opinion matters to fam - paid work outside"

 label var pw_o_comm "Community has opinion - paid work outside"
 label var pw_oe_comm "Community opinion extent - paid work outside"
 label var pw_om_comm "Community opinion matter - paid work outside"
 label var pw_oef_comm "Community opinion matter extent to family - paid work outside"
 label var pw_omf_comm "Community opinion matter to family - paid work outside"

 global referencegroups_lifeevents le_o*
 global referencegroups_work pw_o*

	
/**** Unconditional norms variables ****/
 rename RES_TYPE res_type_norms
 label var res_type_norms "Respondent type for specific norms'questions - check var"
 replace res_type_norms = 4 if missing(res_type_norms)
 label define res_type_norms 1 "Male of working wife, child under 18" 2 "Male of working wife, no child under 18" 3 "Male of non-working wife" 4 "Female"
 label values res_type_norms res_type_norms

//Attitudes and Norms: Rescaling - liberal to conservative
*indvidual behavior 
label define attitudes 1 "conservative" 0 "liberal"

 foreach v in M1A M1B {
	replace `v'=0 if `v'==2
	label val `v' attitudes
 }

 foreach v in M1C M1D M1G M1H {
	replace `v'=0 if `v'==1
	replace `v'=1 if `v'==2
	label val `v' attitudes
 }


*personal opinion, normative, empericial expectations 
 foreach v in M4C M4D M4G M4H {				//the only 4 that are framed positively, thus need to scale them 
	replace `v'=10-`v'
 }


 foreach v in A B C D E F G H {
	forval i=2/4 {
		replace M`i'`v'=M`i'`v'/10
	}
 }


*sanctions 
 foreach v in A B C D G H {
	replace M5`v'=6-M5`v'
	gen M5`v'bin=(M5`v'>=4 & M5`v'<=5)
 }
 
//labeling 
 local thA "A woman's primary responsibility taking care of hh: "
 local thB "Financially providing solely a man's responsibility: "
 local thC "Women don't/shouldn't work outside: "
 local thD "Women don't/shouldn't go outside unaccompanied: "
 local thE "Women working outside for pay brings dishonor: "
 local thF "Women working outside for pay exposes them to harassment: "
 local thG "Women don't/shouldn't leave children: "
 local thH "Women don't/shouldn't work in mixed-gender: "
	
 local n1 "IB"
 local n2 "PNB"
 local n3 "SNE"
 local n4 "SEE"
 local n5 "Sanc."
	
 forval i=1/5 {
	foreach v in A B C D G H {
		label var M`i'`v' "`th`v''`n`i''"
	}
 }
	
 forval i=2/4 {
	foreach v in E F {
		label var M`i'`v' "`th`v''`n`i''"
	}
 }

 foreach v in A B C D G H {
		label var M5`v'bin "`th`v''Sanc."
	}

 global individualbehavior M1A M1B M1C M1D M1G M1H
 global personalopinion M2A M2B M2C M2D M2E M2F M2G M2H
 global normativeexpectations M3A M3B M3C M3D M3E M3F M3G M3H
 global empiricalexpectations M4A M4B M4C M4D M4E M4F M4G M4H
 global sanctions M5A M5B M5C M5D M5G M5H
 global sanctionsbin M5Abin M5Bbin M5Cbin M5Dbin M5Gbin M5Hbin

*aspirations 
 foreach v in M6A M6B M6C M6D M6E {
  gen bin`v'=(`v'==4)
  local `v'_label: var label `v'
  label var bin`v' `"``v'_label'"'
 }

 global aspir M6A M6B M6C M6D M6E
 global aspirbin binM6A binM6B binM6C binM6D binM6E	
 
	
/**** Conditional norms variables ****/
*Conditional Norms
 foreach v in N1__* N2__* {
	label val `v' yesno
 }


 label var N1__1 "is married :PNB"
 label var N2__1 "is married :SNE"

 label var N1__2 "has children under 5 looked after by family :PNB"
 label var N2__2 "has children under 5 looked after by family :SNE"

 label var N1__3 "has children under 5 looked after by non-family :PNB"
 label var N2__3 "has children under 5 looked after by non-family :SNE"

 label var N1__4 "has non-working no-income husband :PNB"
 label var N2__4 "has non-working no-income husband :SNE"

 label var N1__5 "has working husband previously unemployed :PNB"
 label var N2__5 "has working husband previously unemployed :SNE"

 label var N1__6 "is unable to keep up with all household tasks w/o help :PNB"
 label var N2__6 "is unable to keep up with all household tasks w/o help :SNE"

 label var N1__7 "returns home from work after 5 pm :PNB"
 label var N2__7 "returns home from work after 5 pm :SNE"

 label var N1__8 "has migrant husband no remittances :PNB"
 label var N2__8 "has migrant husband no remittances :SNE"

 label var N1__9 "works in a government job :PNB"
 label var N2__9 "works in a government job :SNE"

 label var N1__10 "is well educated :PNB"
 label var N2__10 "is well educated :SNE"

 label var N1__11 "has workplace not close to home :PNB"
 label var N2__11 "has workplace not close to home :SNE"

 label var N1__12 "has job that pays very well :PNB"
 label var N2__12 "has job that pays very well :SNE"

 label var N1__13 "has to occasionally travel for work outside village/city :PNB"
 label var N2__13 "has to occasionally travel for work outside village/city :SNE"

 label var N1__14 "has physically demanding job :PNB"
 label var N2__14 "has physically demanding job :SNE"

 label var N1__15 "works in a hotel/restaurant :PNB"
 label var N2__15 "works in a hotel/restaurant :SNE"

 global cnhh N1__1 N2__1 N1__2 N2__2 N1__3 N2__3 N1__6 N2__6
 global cnsp N1__10 N2__10 N1__4 N2__4 N1__5 N2__5 N1__8 N2__8 
 global jobtype N1__7 N2__7 N1__9 N2__9 N1__11 N2__11 N1__12 N2__12 N1__13 N2__13 N1__14 N2__14 N1__15 N2__15


/**** social desirability ****/ 
 label define agreedisagree 1 "Agree" 0 "Disagree"

 global socialdesirability S1 S2 S3 S4 S5 S6 S7 S8 S9 S10 S11 S12 S13

 foreach var in $socialdesirability {
    recode `var' (2=0)
	label values `var' agreedisagree
  }


  
*save data
 order ID_HH ID quota couple ecological_zone province district cityORmunicipality locality PSU gender age age_cat religion_female religion_male religion_family ethnicity hh_* education migrationstatus_male_self migrationstatus_spouse migrantspouse_* work_30days work_7days paidwork_30days paidwork_7days work_ever paidwork_ever paidwork_lastjob current_work_status work_type work_* *_inc_* chcare_* chcare_r_* chores_help* work_search_dur_exp* work_search_dur_exp2* r_nowork_* jobopp_* year_stopwork r_quitwork_* employees_* entrp_enab_* entrp_govsupp_des* entrp_des* paidjob_f_avail* job_srch_res_* job_srch_portal* chcare_avail_* v_mig_city v_mig_abroad v_mig_base v_mig_bc v_mig_ba v_work_ll v_work_lh v_work_hl v_work_hh res_type_norms le_o* pw_o* M1* M2* M3* M4* M5* M6* binM6A binM6B binM6C binM6D binM6E rgextent* N1__* N2__* S* comments notes 

 drop HL4 HL4_OS HL6_OS ENUM_CODE INTERVIEW_DATE CONSENT IC1 IC2 IC3 HH_* DISPOSITION DISPOSITION_OS L* COMMUNITY COMMUNITY1 RA5 RA5_OS RA2_5 RA3_5 RA4_5 RB5 RB5_OS RB2_5 RB3_5 RB4_5 HH_28_OS_FEMALE HH_28_OS_MALE HH_210 HH_219B HH_219C HH_219D HH_219E HH_219F HH_219F_OS HH_219G HH_218_OS L2_OS L3_OS L4_OS L4__96 entrp_govsupp_des_num HH_2 HH_21

 save "$data\intermediate\NPL_SN_FLFP.dta", replace

}

********************************************************************************
*                  PART 2. Cleaning household-level variables 				   *
********************************************************************************

if $part_2 {
	
*Load dataset 
 use "$data\raw\women_roster_main.dta", clear
 
 clonevar ID_HH = HH_2											
 recast str30 ID_HH, force

 replace HL4 = 19 if HL4_OS=="Daughter-in-law"	
 replace HL4 = 20 if HL4_OS=="Husband's other wife"
 replace HL4 = 21 if HL4_OS=="Household help"				//Note: Gender of HH help is male 							
 replace HL4 = 6 if HL4_OS=="Father-in-law's brother"
 replace HL4 = 6 if HL4_OS=="Grandfather-in-law"
 replace HL4 = 5 if HL4_OS=="Grandmother-in-law"
 replace HL4 = 12 if HL4_OS== "Great grandfather"
 replace HL4 = 11 if HL4_OS=="Great grandmother"
 label define HL4 19 "Daughter-in-law" 20 "Husband's other wife" 21 "Household help", add
 label val HL4 HL4 

 keep ID_HH HH__id HL3 HL4 HL5 HL6 HH_220 

 rename HL3 age 
 rename HL4 relation
 rename HL5 HHhead
 rename HL6 workstatus
 rename HH_220 count_hhmembers_temp

*for all relations except self, count_hhmembers is missing, so fill those in 
 bysort ID_HH: egen count_hhmembers = total(count_hhmembers_temp)
 label var count_hhmembers "Total number of household members"
 drop count_hhmembers_temp
 
 order ID_HH count_hhmembers HH__id relation age workstatus HHhead
 sort ID_HH HH__id

 reshape wide relation age workstatus HHhead, i(ID_HH) j(HH__id)
 order ID_HH count_hhmembers

*number of hh members by gender
 forvalues i=0/11 {
	gen dummy_`i' = 0 
	replace dummy_`i' = 1 if inlist(relation`i',1, 3, 5, 8, 10) | inlist(relation`i',11, 14, 15, 18, 19, 20)
 }

 egen count_hhmembers_f = rowtotal(dummy_0 dummy_1 dummy_2 dummy_3 dummy_4 dummy_5 dummy_6 dummy_7 dummy_8 dummy_9 dummy_10 dummy_11)
 label var count_hhmembers_f "Number of female HH members"

 forvalues i=0/11 {
	drop dummy_`i'
 }

 forvalues i=0/11 {
	gen dummy_`i' = 0 
    replace dummy_`i' = 1 if inlist(relation`i',2, 4, 6, 7, 9) | inlist(relation`i',12, 13, 16, 17, 21)
 }

 egen count_hhmembers_m = rowtotal(dummy_0 dummy_1 dummy_2 dummy_3 dummy_4 dummy_5 dummy_6 dummy_7 dummy_8 dummy_9 dummy_10 dummy_11)
 label var count_hhmembers_m "Number of male HH members"

 forvalues i=0/11 {
	drop dummy_`i'
 }

*number of respondent's children 
 foreach v of varlist relation* {
	gen count_`v'_children = 0 
	replace count_`v'_children = 1 if inlist(`v', 9, 10)
 }

 egen count_children = rowtotal(count_relation0_children count_relation1_children count_relation2_children count_relation3_children count_relation4_children count_relation5_children count_relation6_children count_relation7_children count_relation8_children count_relation9_children count_relation10_children count_relation11_children)
 label var count_children "Number of respondent's children"

 forvalues i=0/11 {
	drop count_relation`i'_children
 }

*number of respondent's female children 
 foreach v of varlist relation* {
	gen count_`v'_children = 0 
	replace count_`v'_children = 1 if inlist(`v', 10)
 }

 egen count_children_female = rowtotal(count_relation0_children count_relation1_children count_relation2_children count_relation3_children count_relation4_children count_relation5_children count_relation6_children count_relation7_children count_relation8_children count_relation9_children count_relation10_children count_relation11_children)
 label var count_children_female "Number of respondent's female children"

 forvalues i=0/11 {
	drop count_relation`i'_children
 }

*number of respondent's male children 
 foreach v of varlist relation* {
	gen count_`v'_children = 0 
	replace count_`v'_children = 1 if inlist(`v', 9)
 }

 egen count_children_male = rowtotal(count_relation0_children count_relation1_children count_relation2_children count_relation3_children count_relation4_children count_relation5_children count_relation6_children count_relation7_children count_relation8_children count_relation9_children count_relation10_children count_relation11_children)
 label var count_children_male "Number of respondent's male children"

 forvalues i=0/11 {
	drop count_relation`i'_children
 }

*number of respondent's children under 5 
 forvalues i=0/11 {
	gen dummy_`i' = 0 
	replace dummy_`i' = 1 if inlist(relation`i', 9, 10)
 }

 forvalues i=0/11 {
	gen dummy_age_`i' = 0 
	replace dummy_age_`i' = 1 if age`i'<5
 }


 forvalues i=0/11 {
	gen count_`i'_childunder5 = 0 
	replace count_`i'_childunder5 = 1 if dummy_`i'==1 & dummy_age_`i'==1
 }

 egen count_childrenunder5 = rowtotal(count_0_childunder5 count_1_childunder5 count_2_childunder5 count_3_childunder5 count_4_childunder5 count_5_childunder5 count_6_childunder5 count_7_childunder5 count_8_childunder5 count_9_childunder5 count_10_childunder5 count_11_childunder5)
 label var count_childrenunder5 "Number of respondent's children under 5 years"

 forvalues i=0/11 {
	drop dummy_`i' dummy_age_`i' count_`i'_childunder5
 }

*number of respondent's children under 18 
 forvalues i=0/11 {
	gen dummy_`i' = 0 
	replace dummy_`i' = 1 if inlist(relation`i', 9, 10)
 }

 forvalues i=0/11 {
	gen dummy_age_`i' = 0 
	replace dummy_age_`i' = 1 if age`i'<18
 }

 forvalues i=0/11 {
	gen count_`i'_childunder18 = 0 
	replace count_`i'_childunder18 = 1 if dummy_`i'==1 & dummy_age_`i'==1
 }

 egen count_childrenunder18 = rowtotal(count_0_childunder18 count_1_childunder18 count_2_childunder18 count_3_childunder18 count_4_childunder18 count_5_childunder18 count_6_childunder18 count_7_childunder18 count_8_childunder18 count_9_childunder18 count_10_childunder18 count_11_childunder18)
 label var count_childrenunder18 "Number of respondent's children under 18 years"

 forvalues i=0/11 {
	drop dummy_`i' dummy_age_`i' count_`i'_childunder18
 }

*number of adolescent girls in the respondent's HH (Adolescents are defined by the United Nations as those between the ages of 10 and 19 years. Source: https://data.unicef.org/topic/adolescents/overview/#:~:text=Defined%20by%20the%20United%20Nations,it%2C%20significant%20growth%20and%20development.)
 forvalues i=0/11 {
	gen dummy_`i' = 0 
	replace dummy_`i' = 1 if inlist(relation`i', 8,10,14,15,18,19)               //While most of the cases are respondent's daughters, adolescent girls also include the following relations to respondent: sister, granddaughter, niece, SIL, DIL.
 }

 forvalues i=0/11 {
	gen dummy_age_`i' = 0 
	replace dummy_age_`i' = 1 if age`i'>=10 & age`i'<=19
 }

 forvalues i=0/11 {
	gen count_`i'_adolesgirls = 0 
	replace count_`i'_adolesgirls = 1 if dummy_`i'==1 & dummy_age_`i'==1
 }

 egen count_adolesgirls = rowtotal(count_0_adolesgirls count_1_adolesgirls count_2_adolesgirls count_3_adolesgirls count_4_adolesgirls count_5_adolesgirls count_6_adolesgirls count_7_adolesgirls count_8_adolesgirls count_9_adolesgirls count_10_adolesgirls count_11_adolesgirls)
 label var count_adolesgirls "Number of adolescent girls in respondent's HH"

 forvalues i=0/11 {
	drop dummy_`i' dummy_age_`i' count_`i'_adolesgirls
 }

*number of females (adolescents or older) in the respondent's HH who are not working (excluding respondent)
// "not working" in this case includes those females who do not work but are looking for work, do not work because they are currently studying, in addition to those who do not work and not looking for work and those under 18 (but older than 10, with no work status info). This is because we would expect women/girls with these statuses to be available to take on HH chores.
 forvalues i=0/11 {
	gen dummy_`i' = 0 
	replace dummy_`i' = 1 if inlist(relation`i', 3,5,8,10) | inlist(relation`i', 11,14,15,18,19,20)
 }

 forvalues i=0/11 {
	gen dummy_age_`i' = 0 
	replace dummy_age_`i' = 1 if age`i'>=10
 }

 forvalues i=0/11 {
	gen count_`i'_females10plusnotwork = 0 
	replace count_`i'_females10plusnotwork = 1 if dummy_`i'==1 & dummy_age_`i'==1
 }	
	
 egen count_females10plusnotwork = rowtotal(count_0_females10plusnotwork count_1_females10plusnotwork count_2_females10plusnotwork count_3_females10plusnotwork count_4_females10plusnotwork count_5_females10plusnotwork count_6_females10plusnotwork count_7_females10plusnotwork count_8_females10plusnotwork count_9_females10plusnotwork count_10_females10plusnotwork count_11_females10plusnotwork)
 label var count_females10plusnotwork "Number of other females (adolescents or older) in respondent's HH who are not working"

 forvalues i=0/11 {
	drop dummy_`i' dummy_age_`i' count_`i'_females10plusnotwork
 }	
		
*number and share of working-age HH members
 forvalues i=0/11 {
	gen dummy_`i' = 0 
	replace dummy_`i' = 1 if age`i'>=18 & age`i'<=59
 }

 egen count_workingage = rowtotal(dummy_0 dummy_1 dummy_2 dummy_3 dummy_4 dummy_5 dummy_6 dummy_7 dummy_8 dummy_9 dummy_10 dummy_11)
 label var count_workingage "Number of working-age (>=18 & <=59) HH members"

 forvalues i=0/11 {
	drop dummy_`i'
 }

 gen share_workingage = count_workingage/count_hhmembers*100
 label var share_workingage "Share of working-age (>=18 & <=59) HH members"

*number and share of working-age female HH members 
 forvalues i=0/11 {
	gen dummy_`i' = 0 
	replace dummy_`i' = 1 if inlist(relation`i',1, 3, 5, 8, 10) | inlist(relation`i',11, 14, 15, 18, 19, 20)
 }


 forvalues i=0/11 {
	gen dummy_age_`i' = 0 
	replace dummy_age_`i' = 1 if age`i'>=18 & age`i'<=59
 }

 forvalues i=0/11 {
	gen count_`i'_workingagefem = 0 
	replace count_`i'_workingagefem = 1 if dummy_`i'==1 & dummy_age_`i'==1
 }

 egen count_workingagefem = rowtotal(count_0_workingagefem count_1_workingagefem count_2_workingagefem count_3_workingagefem count_4_workingagefem count_5_workingagefem count_6_workingagefem count_7_workingagefem count_8_workingagefem count_9_workingagefem count_10_workingagefem count_11_workingagefem)
 label var count_workingagefem "Number of female working-age (>=18 & <=59) HH members"

 forvalues i=0/11 {
	drop dummy_`i' dummy_age_`i' count_`i'_workingagefem
 }

 gen share_workingagefem = count_workingagefem/count_hhmembers_f*100
 label var share_workingagefem "Share of female working-age (>=18 & <=59) HH members"

*number and share of working-age male HH members 
 forvalues i=0/11 {
	gen dummy_`i' = 0 
	replace dummy_`i' = 1 if inlist(relation`i',2, 4, 6, 7, 9) | inlist(relation`i',12, 13, 16, 17, 21)
 }

	
 forvalues i=0/11 {
	gen dummy_age_`i' = 0 
	replace dummy_age_`i' = 1 if age`i'>=18 & age`i'<=59
 }

 forvalues i=0/11 {
	gen count_`i'_workingagemale = 0 
	replace count_`i'_workingagemale = 1 if dummy_`i'==1 & dummy_age_`i'==1
 }

 egen count_workingagemale = rowtotal(count_0_workingagemale count_1_workingagemale count_2_workingagemale count_3_workingagemale count_4_workingagemale count_5_workingagemale count_6_workingagemale count_7_workingagemale count_8_workingagemale count_9_workingagemale count_10_workingagemale count_11_workingagemale)
 label var count_workingagemale "Number of male working-age (>=18 & <=59) HH members"

 forvalues i=0/11 {
	drop dummy_`i' dummy_age_`i' count_`i'_workingagemale
 }

 gen share_workingagemale = count_workingagemale/count_hhmembers_m*100
 label var share_workingagemale "Share of male working-age (>=18 & <=59) HH members"


//Based on workstatus var, let's summarize share of each workstatus response options 
**FEMALES**
 forvalues i=0/11 {
	gen dummy_`i' = 0 
	replace dummy_`i' = 1 if inlist(relation`i',1, 3, 5, 8, 10) | inlist(relation`i',11, 14, 15, 18, 19, 20)
 }


 forvalues i=0/11 {
	gen dummy_age_`i' = 0 
	replace dummy_age_`i' = 1 if age`i'>=18 & age`i'<=59
 }

 *Self-employed/own-account worker (no employees)
 forvalues i=0/11 {
	gen dummy_oaw_`i' = 0 
	replace dummy_oaw_`i' = 1 if workstatus`i'==1
 }

 forvalues i=0/11 {
	gen count_`i'_oaw = 0 
	replace count_`i'_oaw = 1 if dummy_`i'==1 & dummy_age_`i'==1 & dummy_oaw_`i'==1
 }

 egen count_oaw_f = rowtotal(count_0_oaw count_1_oaw count_2_oaw count_3_oaw count_4_oaw count_5_oaw count_6_oaw count_7_oaw count_8_oaw count_9_oaw count_10_oaw count_11_oaw)
 label var count_oaw_f "Number of working-age females who are self-employed/own-account worker (no employees)"

 gen share_oaw_f = count_oaw_f/count_workingagefem*100
 label var share_oaw_f "Share of working-age females who are self-employed/own-account worker (no employees)"

 *Self-employed/business owner with at least 1 employee
 forvalues i=0/11 {
	gen dummy_emp_`i' = 0 
	replace dummy_emp_`i' = 1 if workstatus`i'==2
 }

 forvalues i=0/11 {
	gen count_`i'_emp = 0 
	replace count_`i'_emp = 1 if dummy_`i'==1 & dummy_age_`i'==1 & dummy_emp_`i'==1
 }

 egen count_emp_f = rowtotal(count_0_emp count_1_emp count_2_emp count_3_emp count_4_emp count_5_emp count_6_emp count_7_emp count_8_emp count_9_emp count_10_emp count_11_emp)
 label var count_emp_f "Number of working-age females who are self-employed with at least 1 employee"

 gen share_emp_f = count_emp_f/count_workingagefem*100
 label var share_emp_f "Share of working-age females who are self-employed with at least 1 employee"

*Salaried/wage employee
 forvalues i=0/11 {
	gen dummy_wage_`i' = 0 
	replace dummy_wage_`i' = 1 if workstatus`i'==3
 }

forvalues i=0/11 {
	gen count_`i'_wage = 0 
	replace count_`i'_wage = 1 if dummy_`i'==1 & dummy_age_`i'==1 & dummy_wage_`i'==1
}

 egen count_wage_f = rowtotal(count_0_wage count_1_wage count_2_wage count_3_wage count_4_wage count_5_wage count_6_wage count_7_wage count_8_wage count_9_wage count_10_wage count_11_wage)
 label var count_wage_f "Number of working-age females who are salaried/wage wage employee"

 gen share_wage_f = count_wage_f/count_workingagefem*100
 label var share_wage_f "Share of working-age females who are salaried/wage wage employee"

*Army
 forvalues i=0/11 {
	gen dummy_army_`i' = 0 
	replace dummy_army_`i' = 1 if workstatus`i'==4
 }

 forvalues i=0/11 {
	gen count_`i'_army = 0 
	replace count_`i'_army = 1 if dummy_`i'==1 & dummy_age_`i'==1 & dummy_army_`i'==1
 }

 egen count_army_f = rowtotal(count_0_army count_1_army count_2_army count_3_army count_4_army count_5_army count_6_army count_7_army count_8_army count_9_army count_10_army count_11_army)
 label var count_army_f "Number of working-age females who are in the army"

 gen share_army_f = count_army_f/count_workingagefem*100
 label var share_army_f "Share of working-age females who are in the army"

*Student who also works
 forvalues i=0/11 {
	gen dummy_studwork_`i' = 0 
	replace dummy_studwork_`i' = 1 if workstatus`i'==5
 }

 forvalues i=0/11 {
	gen count_`i'_studwork = 0 
	replace count_`i'_studwork = 1 if dummy_`i'==1 & dummy_age_`i'==1 & dummy_studwork_`i'==1
 }

 egen count_studwork_f = rowtotal(count_0_studwork count_1_studwork count_2_studwork count_3_studwork count_4_studwork count_5_studwork count_6_studwork count_7_studwork count_8_studwork count_9_studwork count_10_studwork count_11_studwork)
 label var count_studwork_f "Number of working-age females who are students who also work"

 gen share_studwork_f = count_studwork_f/count_workingagefem*100
 label var share_studwork_f "Share of working-age females who are students who also work"

*Unpaid worker in the family business
 forvalues i=0/11 {
	gen dummy_unpfam_`i' = 0 
	replace dummy_unpfam_`i' = 1 if workstatus`i'==6
 }

 forvalues i=0/11 {
	gen count_`i'_unpfam = 0 
	replace count_`i'_unpfam = 1 if dummy_`i'==1 & dummy_age_`i'==1 & dummy_unpfam_`i'==1
 }

 egen count_unpfam_f = rowtotal(count_0_unpfam count_1_unpfam count_2_unpfam count_3_unpfam count_4_unpfam count_5_unpfam count_6_unpfam count_7_unpfam count_8_unpfam count_9_unpfam count_10_unpfam count_11_unpfam)
 label var count_unpfam_f "Number of working-age females who are unpaid workers in the family business"

 gen share_unpfam_f = count_unpfam_f/count_workingagefem*100
 label var share_unpfam_f "Share of working-age females who are unpaid workers in the family business"

*Paid worker in the family business
 forvalues i=0/11 {
	gen dummy_pfam_`i' = 0 
	replace dummy_pfam_`i' = 1 if workstatus`i'==7
 }

 forvalues i=0/11 {
	gen count_`i'_pfam = 0 
	replace count_`i'_pfam = 1 if dummy_`i'==1 & dummy_age_`i'==1 & dummy_pfam_`i'==1
 }

 egen count_pfam_f = rowtotal(count_0_pfam count_1_pfam count_2_pfam count_3_pfam count_4_pfam count_5_pfam count_6_pfam count_7_pfam count_8_pfam count_9_pfam count_10_pfam count_11_pfam)
 label var count_pfam_f "Number of working-age females who are paid workers in the family business"

 gen share_pfam_f = count_pfam_f/count_workingagefem*100
 label var share_pfam_f "Share of working-age females who are paid workers in the family business"

*Does not work because currently studying, training, upgrading
 forvalues i=0/11 {
	gen dummy_stud_`i' = 0 
	replace dummy_stud_`i' = 1 if workstatus`i'==8
 }

 forvalues i=0/11 {
	gen count_`i'_stud = 0 
	replace count_`i'_stud = 1 if dummy_`i'==1 & dummy_age_`i'==1 & dummy_stud_`i'==1
 }

 egen count_stud_f = rowtotal(count_0_stud count_1_stud count_2_stud count_3_stud count_4_stud count_5_stud count_6_stud count_7_stud count_8_stud count_9_stud count_10_stud count_11_stud)
 label var count_stud_f "Number of working-age females who are studying, training, upgrading"

 gen share_stud_f = count_stud_f/count_workingagefem*100
 label var share_stud_f "Share of working-age females who are studying, training, upgrading"

*Does not work and not looking for work
 forvalues i=0/11 {
	gen dummy_noworklook_`i' = 0 
	replace dummy_noworklook_`i' = 1 if workstatus`i'==9
 }

 forvalues i=0/11 {
	gen count_`i'_noworklook = 0 
	replace count_`i'_noworklook = 1 if dummy_`i'==1 & dummy_age_`i'==1 & dummy_noworklook_`i'==1
 }

 egen count_noworklook_f = rowtotal(count_0_noworklook count_1_noworklook count_2_noworklook count_3_noworklook count_4_noworklook count_5_noworklook count_6_noworklook count_7_noworklook count_8_noworklook count_9_noworklook count_10_noworklook count_11_noworklook)
 label var count_noworklook_f "Number of working-age females who are not working nor looking for work"

 gen share_noworklook_f = count_noworklook_f/count_workingagefem*100
 label var share_noworklook_f "Share of working-age females who are not working nor looking for work"

*Does not work but is looking for work
 forvalues i=0/11 {
	gen dummy_noworkyeslook_`i' = 0 
	replace dummy_noworkyeslook_`i' = 1 if workstatus`i'==10
 }

 forvalues i=0/11 {
	gen count_`i'_noworkyeslook = 0 
	replace count_`i'_noworkyeslook = 1 if dummy_`i'==1 & dummy_age_`i'==1 & dummy_noworkyeslook_`i'==1
 }

 egen count_noworkyeslook_f = rowtotal(count_0_noworkyeslook count_1_noworkyeslook count_2_noworkyeslook count_3_noworkyeslook count_4_noworkyeslook count_5_noworkyeslook count_6_noworkyeslook count_7_noworkyeslook count_8_noworkyeslook count_9_noworkyeslook count_10_noworkyeslook count_11_noworkyeslook)
 label var count_noworkyeslook_f "Number of working-age females who are not working but is looking for work"

 gen share_noworkyeslook_f = count_noworkyeslook_f/count_workingagefem*100
 label var share_noworkyeslook_f "Share of working-age females who are not working but is looking for work"


 forvalues i=0/11 {
	drop dummy_`i' dummy_age_`i' dummy_oaw_`i' count_`i'_oaw dummy_emp_`i' count_`i'_emp dummy_wage_`i' count_`i'_wage dummy_army_`i' count_`i'_army dummy_studwork_`i' count_`i'_studwork dummy_unpfam_`i' count_`i'_unpfam dummy_pfam_`i' count_`i'_pfam dummy_stud_`i' count_`i'_stud dummy_noworklook_`i' count_`i'_noworklook dummy_noworkyeslook_`i' count_`i'_noworkyeslook
 }

 
**MALES**
 forvalues i=0/11 {
	gen dummy_`i' = 0 
	replace dummy_`i' = 1 if inlist(relation`i',2, 4, 6, 7, 9) | inlist(relation`i',12, 13, 16, 17, 21)
 }

 forvalues i=0/11 {
	gen dummy_age_`i' = 0 
	replace dummy_age_`i' = 1 if age`i'>=18 & age`i'<=59
 }

*Self-employed/own-account worker (no employees)
 forvalues i=0/11 {
	gen dummy_oaw_`i' = 0 
	replace dummy_oaw_`i' = 1 if workstatus`i'==1
 }

 forvalues i=0/11 {
	gen count_`i'_oaw = 0 
	replace count_`i'_oaw = 1 if dummy_`i'==1 & dummy_age_`i'==1 & dummy_oaw_`i'==1
 }

 egen count_oaw_m = rowtotal(count_0_oaw count_1_oaw count_2_oaw count_3_oaw count_4_oaw count_5_oaw count_6_oaw count_7_oaw count_8_oaw count_9_oaw count_10_oaw count_11_oaw)
 label var count_oaw_m "Number of working-age males who are self-employed/own-account worker (no employees)"

 gen share_oaw_m = count_oaw_m/count_workingagemale*100
 label var share_oaw_m "Share of working-age males who are self-employed/own-account worker (no employees)"

*Self-employed/business owner with at least 1 employee
 forvalues i=0/11 {
	gen dummy_emp_`i' = 0 
	replace dummy_emp_`i' = 1 if workstatus`i'==2
 }

 forvalues i=0/11 {
	gen count_`i'_emp = 0 
	replace count_`i'_emp = 1 if dummy_`i'==1 & dummy_age_`i'==1 & dummy_emp_`i'==1
 }

 egen count_emp_m = rowtotal(count_0_emp count_1_emp count_2_emp count_3_emp count_4_emp count_5_emp count_6_emp count_7_emp count_8_emp count_9_emp count_10_emp count_11_emp)
 label var count_emp_m "Number of working-age males who are self-employed with at least 1 employee"

 gen share_emp_m = count_emp_m/count_workingagemale*100
 label var share_emp_m "Share of working-age males who are self-employed with at least 1 employee"

*Salaried/wage employee
 forvalues i=0/11 {
	gen dummy_wage_`i' = 0 
	replace dummy_wage_`i' = 1 if workstatus`i'==3
 }

 forvalues i=0/11 {
	gen count_`i'_wage = 0 
	replace count_`i'_wage = 1 if dummy_`i'==1 & dummy_age_`i'==1 & dummy_wage_`i'==1
 }

 egen count_wage_m = rowtotal(count_0_wage count_1_wage count_2_wage count_3_wage count_4_wage count_5_wage count_6_wage count_7_wage count_8_wage count_9_wage count_10_wage count_11_wage)
 label var count_wage_m "Number of working-age males who are salaried/wage wage employee"

 gen share_wage_m = count_wage_m/count_workingagemale*100
 label var share_wage_m "Share of working-age males who are salaried/wage wage employee"

*Army
 forvalues i=0/11 {
	gen dummy_army_`i' = 0 
	replace dummy_army_`i' = 1 if workstatus`i'==4
 }

 forvalues i=0/11 {
	gen count_`i'_army = 0 
	replace count_`i'_army = 1 if dummy_`i'==1 & dummy_age_`i'==1 & dummy_army_`i'==1
 }

 egen count_army_m = rowtotal(count_0_army count_1_army count_2_army count_3_army count_4_army count_5_army count_6_army count_7_army count_8_army count_9_army count_10_army count_11_army)
 label var count_army_m "Number of working-age males who are in the army"

 gen share_army_m = count_army_m/count_workingagemale*100
 label var share_army_m "Share of working-age males who are in the army"

*Student who also works
 forvalues i=0/11 {
	gen dummy_studwork_`i' = 0 
	replace dummy_studwork_`i' = 1 if workstatus`i'==5
 }

 forvalues i=0/11 {
	gen count_`i'_studwork = 0 
	replace count_`i'_studwork = 1 if dummy_`i'==1 & dummy_age_`i'==1 & dummy_studwork_`i'==1
 }

 egen count_studwork_m = rowtotal(count_0_studwork count_1_studwork count_2_studwork count_3_studwork count_4_studwork count_5_studwork count_6_studwork count_7_studwork count_8_studwork count_9_studwork count_10_studwork count_11_studwork)
 label var count_studwork_m "Number of working-age males who are students who also work"

 gen share_studwork_m = count_studwork_m/count_workingagemale*100
 label var share_studwork_m "Share of working-age males who are students who also work"

*Unpaid worker in the family business
 forvalues i=0/11 {
	gen dummy_unpfam_`i' = 0 
	replace dummy_unpfam_`i' = 1 if workstatus`i'==6
 }

 forvalues i=0/11 {
	gen count_`i'_unpfam = 0 
	replace count_`i'_unpfam = 1 if dummy_`i'==1 & dummy_age_`i'==1 & dummy_unpfam_`i'==1
 }

 egen count_unpfam_m = rowtotal(count_0_unpfam count_1_unpfam count_2_unpfam count_3_unpfam count_4_unpfam count_5_unpfam count_6_unpfam count_7_unpfam count_8_unpfam count_9_unpfam count_10_unpfam count_11_unpfam)
 label var count_unpfam_m "Number of working-age males who are unpaid workers in the family business"

 gen share_unpfam_m = count_unpfam_m/count_workingagemale*100
 label var share_unpfam_m "Share of working-age males who are unpaid workers in the family business"

*Paid worker in the family business
 forvalues i=0/11 {
	gen dummy_pfam_`i' = 0 
	replace dummy_pfam_`i' = 1 if workstatus`i'==7
 }

 forvalues i=0/11 {
	gen count_`i'_pfam = 0 
	replace count_`i'_pfam = 1 if dummy_`i'==1 & dummy_age_`i'==1 & dummy_pfam_`i'==1
 }

 egen count_pfam_m = rowtotal(count_0_pfam count_1_pfam count_2_pfam count_3_pfam count_4_pfam count_5_pfam count_6_pfam count_7_pfam count_8_pfam count_9_pfam count_10_pfam count_11_pfam)
 label var count_pfam_m "Number of working-age males who are paid workers in the family business"

 gen share_pfam_m = count_pfam_m/count_workingagemale*100
 label var share_pfam_m "Share of working-age males who are paid workers in the family business"

*Does not work because currently studying, training, upgrading
 forvalues i=0/11 {
	gen dummy_stud_`i' = 0 
	replace dummy_stud_`i' = 1 if workstatus`i'==8
 }

 forvalues i=0/11 {
	gen count_`i'_stud = 0 
	replace count_`i'_stud = 1 if dummy_`i'==1 & dummy_age_`i'==1 & dummy_stud_`i'==1
 }

 egen count_stud_m = rowtotal(count_0_stud count_1_stud count_2_stud count_3_stud count_4_stud count_5_stud count_6_stud count_7_stud count_8_stud count_9_stud count_10_stud count_11_stud)
 label var count_stud_m "Number of working-age males who are studying, training, upgrading"

 gen share_stud_m = count_stud_m/count_workingagemale*100
 label var share_stud_m "Share of working-age males who are studying, training, upgrading"

*Does not work and not looking for work
 forvalues i=0/11 {
	gen dummy_noworklook_`i' = 0 
	replace dummy_noworklook_`i' = 1 if workstatus`i'==9
 }

 forvalues i=0/11 {
	gen count_`i'_noworklook = 0 
	replace count_`i'_noworklook = 1 if dummy_`i'==1 & dummy_age_`i'==1 & dummy_noworklook_`i'==1
 }

 egen count_noworklook_m = rowtotal(count_0_noworklook count_1_noworklook count_2_noworklook count_3_noworklook count_4_noworklook count_5_noworklook count_6_noworklook count_7_noworklook count_8_noworklook count_9_noworklook count_10_noworklook count_11_noworklook)
 label var count_noworklook_m "Number of working-age males who are not working nor looking for work"

 gen share_noworklook_m = count_noworklook_m/count_workingagemale*100
 label var share_noworklook_m "Share of working-age males who are not working nor looking for work"

*Does not work but is looking for work
 forvalues i=0/11 {
	gen dummy_noworkyeslook_`i' = 0 
	replace dummy_noworkyeslook_`i' = 1 if workstatus`i'==10
 }

 forvalues i=0/11 {
	gen count_`i'_noworkyeslook = 0 
	replace count_`i'_noworkyeslook = 1 if dummy_`i'==1 & dummy_age_`i'==1 & dummy_noworkyeslook_`i'==1
 }

 egen count_noworkyeslook_m = rowtotal(count_0_noworkyeslook count_1_noworkyeslook count_2_noworkyeslook count_3_noworkyeslook count_4_noworkyeslook count_5_noworkyeslook count_6_noworkyeslook count_7_noworkyeslook count_8_noworkyeslook count_9_noworkyeslook count_10_noworkyeslook count_11_noworkyeslook)
 label var count_noworkyeslook_m "Number of working-age males who are not working but is looking for work"

 gen share_noworkyeslook_m = count_noworkyeslook_m/count_workingagemale*100
 label var share_noworkyeslook_m "Share of working-age males who are not working but is looking for work"


 forvalues i=0/11 {
	drop dummy_`i' dummy_age_`i' dummy_oaw_`i' count_`i'_oaw dummy_emp_`i' count_`i'_emp dummy_wage_`i' count_`i'_wage dummy_army_`i' count_`i'_army dummy_studwork_`i' count_`i'_studwork dummy_unpfam_`i' count_`i'_unpfam dummy_pfam_`i' count_`i'_pfam dummy_stud_`i' count_`i'_stud dummy_noworklook_`i' count_`i'_noworklook dummy_noworkyeslook_`i' count_`i'_noworkyeslook
 }

**ALL**
 forvalues i=0/11 {
	gen dummy_age_`i' = 0 
	replace dummy_age_`i' = 1 if age`i'>=18 & age`i'<=59
 }

*Self-employed/own-account worker (no employees)
 forvalues i=0/11 {
	gen dummy_oaw_`i' = 0 
	replace dummy_oaw_`i' = 1 if workstatus`i'==1
 }

 forvalues i=0/11 {
	gen count_`i'_oaw = 0 
	replace count_`i'_oaw = 1 if dummy_age_`i'==1 & dummy_oaw_`i'==1
 }

 egen count_oaw = rowtotal(count_0_oaw count_1_oaw count_2_oaw count_3_oaw count_4_oaw count_5_oaw count_6_oaw count_7_oaw count_8_oaw count_9_oaw count_10_oaw count_11_oaw)
 label var count_oaw "Number of working-age members who are self-employed/own-account worker (no employees)"

 gen share_oaw = count_oaw/count_workingage*100
 label var share_oaw "Share of working-age members who are self-employed/own-account worker (no employees)"

*Self-employed/business owner with at least 1 employee
 forvalues i=0/11 {
	gen dummy_emp_`i' = 0 
	replace dummy_emp_`i' = 1 if workstatus`i'==2
 }

 forvalues i=0/11 {
	gen count_`i'_emp = 0 
	replace count_`i'_emp = 1 if dummy_age_`i'==1 & dummy_emp_`i'==1
 }

 egen count_emp = rowtotal(count_0_emp count_1_emp count_2_emp count_3_emp count_4_emp count_5_emp count_6_emp count_7_emp count_8_emp count_9_emp count_10_emp count_11_emp)
 label var count_emp "Number of working-age members who are self-employed with at least 1 employee"

 gen share_emp = count_emp/count_workingage*100
 label var share_emp "Share of working-age members who are self-employed with at least 1 employee"

*Salaried/wage employee
 forvalues i=0/11 {
	gen dummy_wage_`i' = 0 
	replace dummy_wage_`i' = 1 if workstatus`i'==3
 }

 forvalues i=0/11 {
	gen count_`i'_wage = 0 
	replace count_`i'_wage = 1 if dummy_age_`i'==1 & dummy_wage_`i'==1
 }

 egen count_wage = rowtotal(count_0_wage count_1_wage count_2_wage count_3_wage count_4_wage count_5_wage count_6_wage count_7_wage count_8_wage count_9_wage count_10_wage count_11_wage)
 label var count_wage "Number of working-age members who are salaried/wage wage employee"

 gen share_wage = count_wage/count_workingage*100
 label var share_wage "Share of working-age members who are salaried/wage wage employee"

*Army
 forvalues i=0/11 {
	gen dummy_army_`i' = 0 
	replace dummy_army_`i' = 1 if workstatus`i'==4
 }

 forvalues i=0/11 {
	gen count_`i'_army = 0 
	replace count_`i'_army = 1 if dummy_age_`i'==1 & dummy_army_`i'==1
 }

 egen count_army = rowtotal(count_0_army count_1_army count_2_army count_3_army count_4_army count_5_army count_6_army count_7_army count_8_army count_9_army count_10_army count_11_army)
 label var count_army "Number of working-age members who are in the army"

 gen share_army = count_army/count_workingage*100
 label var share_army "Share of working-age members who are in the army"

*Student who also works
 forvalues i=0/11 {
	gen dummy_studwork_`i' = 0 
	replace dummy_studwork_`i' = 1 if workstatus`i'==5
 }

 forvalues i=0/11 {
	gen count_`i'_studwork = 0 
	replace count_`i'_studwork = 1 if dummy_age_`i'==1 & dummy_studwork_`i'==1
 }

 egen count_studwork = rowtotal(count_0_studwork count_1_studwork count_2_studwork count_3_studwork count_4_studwork count_5_studwork count_6_studwork count_7_studwork count_8_studwork count_9_studwork count_10_studwork count_11_studwork)
 label var count_studwork "Number of working-age members who are students who also work"

 gen share_studwork = count_studwork/count_workingage*100
 label var share_studwork "Share of working-age members who are students who also work"

*Unpaid worker in the family business
 forvalues i=0/11 {
	gen dummy_unpfam_`i' = 0 
	replace dummy_unpfam_`i' = 1 if workstatus`i'==6
 }

 forvalues i=0/11 {
	gen count_`i'_unpfam = 0 
	replace count_`i'_unpfam = 1 if dummy_age_`i'==1 & dummy_unpfam_`i'==1
 }

 egen count_unpfam = rowtotal(count_0_unpfam count_1_unpfam count_2_unpfam count_3_unpfam count_4_unpfam count_5_unpfam count_6_unpfam count_7_unpfam count_8_unpfam count_9_unpfam count_10_unpfam count_11_unpfam)
 label var count_unpfam "Number of working-age members who are unpaid workers in the family business"

 gen share_unpfam = count_unpfam/count_workingage*100
 label var share_unpfam "Share of working-age members who are unpaid workers in the family business"

*Paid worker in the family business
 forvalues i=0/11 {
	gen dummy_pfam_`i' = 0 
	replace dummy_pfam_`i' = 1 if workstatus`i'==7
 }

 forvalues i=0/11 {
	gen count_`i'_pfam = 0 
	replace count_`i'_pfam = 1 if dummy_age_`i'==1 & dummy_pfam_`i'==1
 }

 egen count_pfam = rowtotal(count_0_pfam count_1_pfam count_2_pfam count_3_pfam count_4_pfam count_5_pfam count_6_pfam count_7_pfam count_8_pfam count_9_pfam count_10_pfam count_11_pfam)
 label var count_pfam "Number of working-age members who are paid workers in the family business"

 gen share_pfam = count_pfam/count_workingage*100
 label var share_pfam "Share of working-age members who are paid workers in the family business"

*Does not work because currently studying, training, upgrading
 forvalues i=0/11 {
	gen dummy_stud_`i' = 0 
	replace dummy_stud_`i' = 1 if workstatus`i'==8
 }

 forvalues i=0/11 {
	gen count_`i'_stud = 0 
	replace count_`i'_stud = 1 if dummy_age_`i'==1 & dummy_stud_`i'==1
 }

 egen count_stud = rowtotal(count_0_stud count_1_stud count_2_stud count_3_stud count_4_stud count_5_stud count_6_stud count_7_stud count_8_stud count_9_stud count_10_stud count_11_stud)
 label var count_stud "Number of working-age members who are studying, training, upgrading"

 gen share_stud = count_stud/count_workingage*100
 label var share_stud "Share of working-age members who are studying, training, upgrading"

*Does not work and not looking for work
 forvalues i=0/11 {
	gen dummy_noworklook_`i' = 0 
	replace dummy_noworklook_`i' = 1 if workstatus`i'==9
 }

 forvalues i=0/11 {
	gen count_`i'_noworklook = 0 
	replace count_`i'_noworklook = 1 if dummy_age_`i'==1 & dummy_noworklook_`i'==1
 }

 egen count_noworklook = rowtotal(count_0_noworklook count_1_noworklook count_2_noworklook count_3_noworklook count_4_noworklook count_5_noworklook count_6_noworklook count_7_noworklook count_8_noworklook count_9_noworklook count_10_noworklook count_11_noworklook)
 label var count_noworklook "Number of working-age members who are not working nor looking for work"

 gen share_noworklook = count_noworklook/count_workingage*100
 label var share_noworklook "Share of working-age members who are not working nor looking for work"

*Does not work but is looking for work
 forvalues i=0/11 {
	gen dummy_noworkyeslook_`i' = 0 
	replace dummy_noworkyeslook_`i' = 1 if workstatus`i'==10
 }

 forvalues i=0/11 {
	gen count_`i'_noworkyeslook = 0 
	replace count_`i'_noworkyeslook = 1 if dummy_age_`i'==1 & dummy_noworkyeslook_`i'==1
 }

 egen count_noworkyeslook = rowtotal(count_0_noworkyeslook count_1_noworkyeslook count_2_noworkyeslook count_3_noworkyeslook count_4_noworkyeslook count_5_noworkyeslook count_6_noworkyeslook count_7_noworkyeslook count_8_noworkyeslook count_9_noworkyeslook count_10_noworkyeslook count_11_noworkyeslook)
 label var count_noworkyeslook "Number of working-age members who are not working but is looking for work"

 gen share_noworkyeslook = count_noworkyeslook/count_workingage*100
 label var share_noworkyeslook "Share of working-age members who are not working but is looking for work"


 forvalues i=0/11 {
	drop dummy_age_`i' dummy_oaw_`i' count_`i'_oaw dummy_emp_`i' count_`i'_emp dummy_wage_`i' count_`i'_wage dummy_army_`i' count_`i'_army dummy_studwork_`i' count_`i'_studwork dummy_unpfam_`i' count_`i'_unpfam dummy_pfam_`i' count_`i'_pfam dummy_stud_`i' count_`i'_stud dummy_noworklook_`i' count_`i'_noworklook dummy_noworkyeslook_`i' count_`i'_noworkyeslook
 }
 
 
///laborforce_s includes Self-employed or own-account worker, Salaried/wage employee, Army, Student who also works, Unpaid worker in the family business, Paid worker in the family business, Does not work because currently studying, training, upgradin, Does not work but is looking for work
///laborforce includes all above except does not work because currently studying, training, upgradin

*number of working-age female HH members in the laborforce_s 
forvalues i=0/11 {
	gen dummy_`i' = 0 
	replace dummy_`i' = 1 if inlist(relation`i',1, 3, 5, 8, 10) | inlist(relation`i',11, 14, 15, 18, 19, 20)
}


forvalues i=0/11 {
	gen dummy_age_`i' = 0 
	replace dummy_age_`i' = 1 if age`i'>=18 & age`i'<=59
}


forvalues i=0/11 {
	gen dummy_workstatus_`i' = 0 
	replace dummy_workstatus_`i' = 1 if inlist(workstatus`i', 1, 2, 3, 4, 5) | inlist(workstatus`i', 6, 7, 8, 10) 
}


forvalues i=0/11 {
	gen count_`i'_workingfem = 0 
	replace count_`i'_workingfem = 1 if dummy_`i'==1 & dummy_age_`i'==1 & dummy_workstatus_`i'==1
}


egen count_lf_s_fem = rowtotal(count_0_workingfem count_1_workingfem count_2_workingfem count_3_workingfem count_4_workingfem count_5_workingfem count_6_workingfem count_7_workingfem count_8_workingfem count_9_workingfem count_10_workingfem count_11_workingfem)
label var count_lf_s_fem "Number of female working-age (>=18 & <=59) HH members in labor force inc. study"

forvalues i=0/11 {
	drop dummy_`i' dummy_age_`i' dummy_workstatus_`i' count_`i'_workingfem
}



*number and share of working-age HH members in the laborforce
forvalues i=0/11 {
	gen dummy_age_`i' = 0 
	replace dummy_age_`i' = 1 if age`i'>=18 & age`i'<=59
}


forvalues i=0/11 {
	gen dummy_workstatus_`i' = 0 
	replace dummy_workstatus_`i' = 1 if inlist(workstatus`i', 1, 2, 3, 4, 5) | inlist(workstatus`i', 6, 7, 10) 
}


forvalues i=0/11 {
	gen count_`i'_working = 0 
	replace count_`i'_working = 1 if dummy_age_`i'==1 & dummy_workstatus_`i'==1
}

egen count_lf = rowtotal(count_0_working count_1_working count_2_working count_3_working count_4_working count_5_working count_6_working count_7_working count_8_working count_9_working count_10_working count_11_working)
label var count_lf "Number of working-age (>=18 & <=59) HH members in labor force"

forvalues i=0/11 {
	drop dummy_age_`i' dummy_workstatus_`i' count_`i'_working
}

gen share_lf = count_lf/count_workingage*100
label var share_lf "Share of working-age (>=18 & <=59) HH members in labor force"

*number and share of working-age female HH members in the laborforce
forvalues i=0/11 {
	gen dummy_`i' = 0 
	replace dummy_`i' = 1 if inlist(relation`i',1, 3, 5, 8, 10) | inlist(relation`i',11, 14, 15, 18, 19, 20)
}

forvalues i=0/11 {
	gen dummy_age_`i' = 0 
	replace dummy_age_`i' = 1 if age`i'>=18 & age`i'<=59
}

forvalues i=0/11 {
	gen dummy_workstatus_`i' = 0 
	replace dummy_workstatus_`i' = 1 if inlist(workstatus`i', 1, 2, 3, 4, 5) | inlist(workstatus`i', 6, 7, 10) 
}

forvalues i=0/11 {
	gen count_`i'_workingfem = 0 
	replace count_`i'_workingfem = 1 if dummy_`i'==1 & dummy_age_`i'==1 & dummy_workstatus_`i'==1
}

egen count_lf_fem = rowtotal(count_0_workingfem count_1_workingfem count_2_workingfem count_3_workingfem count_4_workingfem count_5_workingfem count_6_workingfem count_7_workingfem count_8_workingfem count_9_workingfem count_10_workingfem count_11_workingfem)
label var count_lf_fem "Number of female working-age (>=18 & <=59) HH members in labor force"

forvalues i=0/11 {
	drop dummy_`i' dummy_age_`i' dummy_workstatus_`i' count_`i'_workingfem
}

gen share_lf_fem = count_lf_fem/count_workingagefem*100
label var share_lf_fem "Share of female working-age (>=18 & <=59) HH members in labor force"

*number of working-age male HH members in the laborforce_s 
forvalues i=0/11 {
	gen dummy_`i' = 0 
	replace dummy_`i' = 1 if inlist(relation`i',2, 4, 6, 7, 9) | inlist(relation`i',12, 13, 16, 17, 21)
}

forvalues i=0/11 {
	gen dummy_age_`i' = 0 
	replace dummy_age_`i' = 1 if age`i'>=18 & age`i'<=59
}

forvalues i=0/11 {
	gen dummy_workstatus_`i' = 0 
	replace dummy_workstatus_`i' = 1 if inlist(workstatus`i', 1, 2, 3, 4, 5) | inlist(workstatus`i', 6, 7, 8, 10) 
}

forvalues i=0/11 {
	gen count_`i'_workingmale = 0 
	replace count_`i'_workingmale = 1 if dummy_`i'==1 & dummy_age_`i'==1 & dummy_workstatus_`i'==1
}

egen count_lf_s_male = rowtotal(count_0_workingmale count_1_workingmale count_2_workingmale count_3_workingmale count_4_workingmale count_5_workingmale count_6_workingmale count_7_workingmale count_8_workingmale count_9_workingmale count_10_workingmale count_11_workingmale)
label var count_lf_s_male "Number of male working-age (>=18 & <=59) HH members in labor force inc. study"

forvalues i=0/11 {
	drop dummy_`i' dummy_age_`i' dummy_workstatus_`i' count_`i'_workingmale
}


*number and share of working-age male HH members in the laborforce
forvalues i=0/11 {
	gen dummy_`i' = 0 
	replace dummy_`i' = 1 if inlist(relation`i',2, 4, 6, 7, 9) | inlist(relation`i',12, 13, 16, 17, 21)
}

forvalues i=0/11 {
	gen dummy_age_`i' = 0 
	replace dummy_age_`i' = 1 if age`i'>=18 & age`i'<=59
}

forvalues i=0/11 {
	gen dummy_workstatus_`i' = 0 
	replace dummy_workstatus_`i' = 1 if inlist(workstatus`i', 1, 2, 3, 4, 5) | inlist(workstatus`i', 6, 7, 10) 
}

forvalues i=0/11 {
	gen count_`i'_workingmale = 0 
	replace count_`i'_workingmale = 1 if dummy_`i'==1 & dummy_age_`i'==1 & dummy_workstatus_`i'==1
}

egen count_lf_male = rowtotal(count_0_workingmale count_1_workingmale count_2_workingmale count_3_workingmale count_4_workingmale count_5_workingmale count_6_workingmale count_7_workingmale count_8_workingmale count_9_workingmale count_10_workingmale count_11_workingmale)
label var count_lf_male "Number of male working-age (>=18 & <=59) HH members in labor force"

forvalues i=0/11 {
	drop dummy_`i' dummy_age_`i' dummy_workstatus_`i' count_`i'_workingmale
}

gen share_lf_male = count_lf_male/count_workingagemale*100
label var share_lf_male "Share of male working-age (>=18 & <=59) HH members in labor force"


*share of working-age male HH members out of labor force  
 gen share_outlf = share_stud + share_noworklook
 label var share_outlf "Share of working-age (>=18 & <=59) HH members out of labor force"
 
 gen share_outlf_m = share_stud_m + share_noworklook_m
 label var share_outlf_m "Share of male working-age (>=18 & <=59) HH members out of labor force"
 
 gen share_outlf_f = share_stud_f + share_noworklook_f
 label var share_outlf_f "Share of female working-age (>=18 & <=59) HH members out of labor force"

//Based on those in the labor force, let's summarize share of each workstatus response options within the labor force
**FEMALES**
forvalues i=0/11 {
	gen dummy_`i' = 0 
	replace dummy_`i' = 1 if inlist(relation`i',1, 3, 5, 8, 10) | inlist(relation`i',11, 14, 15, 18, 19, 20)
}

forvalues i=0/11 {
	gen dummy_age_`i' = 0 
	replace dummy_age_`i' = 1 if age`i'>=18 & age`i'<=59
}

*Self-employed/own-account worker (no employees)
forvalues i=0/11 {
	gen dummy_oaw_`i' = 0 
	replace dummy_oaw_`i' = 1 if workstatus`i'==1
}

forvalues i=0/11 {
	gen count_`i'_oaw = 0 
	replace count_`i'_oaw = 1 if dummy_`i'==1 & dummy_age_`i'==1 & dummy_oaw_`i'==1
}

egen count_oaw_lf_f = rowtotal(count_0_oaw count_1_oaw count_2_oaw count_3_oaw count_4_oaw count_5_oaw count_6_oaw count_7_oaw count_8_oaw count_9_oaw count_10_oaw count_11_oaw)
label var count_oaw_lf_f "Number of females in labor force who are self-employed/own-account worker (no employees)"

gen share_oaw_lf_f = count_oaw_lf_f/count_lf_fem*100
label var share_oaw_lf_f "Share of females in labor force who are self-employed/own-account worker (no employees)"

*Self-employed/business owner with at least 1 employee
forvalues i=0/11 {
	gen dummy_emp_`i' = 0 
	replace dummy_emp_`i' = 1 if workstatus`i'==2
}

forvalues i=0/11 {
	gen count_`i'_emp = 0 
	replace count_`i'_emp = 1 if dummy_`i'==1 & dummy_age_`i'==1 & dummy_emp_`i'==1
}

egen count_emp_lf_f = rowtotal(count_0_emp count_1_emp count_2_emp count_3_emp count_4_emp count_5_emp count_6_emp count_7_emp count_8_emp count_9_emp count_10_emp count_11_emp)
label var count_emp_lf_f "Number of females in labor force who are self-employed with at least 1 employee"

gen share_emp_lf_f = count_emp_lf_f/count_lf_fem*100
label var share_emp_lf_f "Share of females in labor force who are self-employed with at least 1 employee"

*Salaried/wage employee
forvalues i=0/11 {
	gen dummy_wage_`i' = 0 
	replace dummy_wage_`i' = 1 if workstatus`i'==3
}

forvalues i=0/11 {
	gen count_`i'_wage = 0 
	replace count_`i'_wage = 1 if dummy_`i'==1 & dummy_age_`i'==1 & dummy_wage_`i'==1
}

egen count_wage_lf_f = rowtotal(count_0_wage count_1_wage count_2_wage count_3_wage count_4_wage count_5_wage count_6_wage count_7_wage count_8_wage count_9_wage count_10_wage count_11_wage)
label var count_wage_lf_f "Number of females in labor force who are salaried/wage wage employee"

gen share_wage_lf_f = count_wage_lf_f/count_lf_fem*100
label var share_wage_lf_f "Share of females in labor force who are salaried/wage wage employee"

*Army
forvalues i=0/11 {
	gen dummy_army_`i' = 0 
	replace dummy_army_`i' = 1 if workstatus`i'==4
}

forvalues i=0/11 {
	gen count_`i'_army = 0 
	replace count_`i'_army = 1 if dummy_`i'==1 & dummy_age_`i'==1 & dummy_army_`i'==1
}

egen count_army_lf_f = rowtotal(count_0_army count_1_army count_2_army count_3_army count_4_army count_5_army count_6_army count_7_army count_8_army count_9_army count_10_army count_11_army)
label var count_army_lf_f "Number of females in labor force who are in the army"

gen share_army_lf_f = count_army_lf_f/count_lf_fem*100
label var share_army_lf_f "Share of females in labor force who are in the army"

*Student who also works
forvalues i=0/11 {
	gen dummy_studwork_`i' = 0 
	replace dummy_studwork_`i' = 1 if workstatus`i'==5
}

forvalues i=0/11 {
	gen count_`i'_studwork = 0 
	replace count_`i'_studwork = 1 if dummy_`i'==1 & dummy_age_`i'==1 & dummy_studwork_`i'==1
}

egen count_studwork_lf_f = rowtotal(count_0_studwork count_1_studwork count_2_studwork count_3_studwork count_4_studwork count_5_studwork count_6_studwork count_7_studwork count_8_studwork count_9_studwork count_10_studwork count_11_studwork)
label var count_studwork_lf_f "Number of females in labor force who are students who also work"

gen share_studwork_lf_f = count_studwork_lf_f/count_lf_fem*100
label var share_studwork_lf_f "Share of females in labor force who are students who also work"

*Unpaid worker in the family business
forvalues i=0/11 {
	gen dummy_unpfam_`i' = 0 
	replace dummy_unpfam_`i' = 1 if workstatus`i'==6
}

forvalues i=0/11 {
	gen count_`i'_unpfam = 0 
	replace count_`i'_unpfam = 1 if dummy_`i'==1 & dummy_age_`i'==1 & dummy_unpfam_`i'==1
}

egen count_unpfam_lf_f = rowtotal(count_0_unpfam count_1_unpfam count_2_unpfam count_3_unpfam count_4_unpfam count_5_unpfam count_6_unpfam count_7_unpfam count_8_unpfam count_9_unpfam count_10_unpfam count_11_unpfam)
label var count_unpfam_lf_f "Number of females in labor force who are unpaid workers in the family business"

gen share_unpfam_lf_f = count_unpfam_lf_f/count_lf_fem*100
label var share_unpfam_lf_f "Share of females in labor force who are unpaid workers in the family business"

*Paid worker in the family business
forvalues i=0/11 {
	gen dummy_pfam_`i' = 0 
	replace dummy_pfam_`i' = 1 if workstatus`i'==7
}

forvalues i=0/11 {
	gen count_`i'_pfam = 0 
	replace count_`i'_pfam = 1 if dummy_`i'==1 & dummy_age_`i'==1 & dummy_pfam_`i'==1
}

egen count_pfam_lf_f = rowtotal(count_0_pfam count_1_pfam count_2_pfam count_3_pfam count_4_pfam count_5_pfam count_6_pfam count_7_pfam count_8_pfam count_9_pfam count_10_pfam count_11_pfam)
label var count_pfam_lf_f "Number of females in labor force who are paid workers in the family business"

gen share_pfam_lf_f = count_pfam_lf_f/count_lf_fem*100
label var share_pfam_lf_f "Share of females in labor force who are paid workers in the family business"

*Does not work but is looking for work
forvalues i=0/11 {
	gen dummy_noworkyeslook_`i' = 0 
	replace dummy_noworkyeslook_`i' = 1 if workstatus`i'==10
}

forvalues i=0/11 {
	gen count_`i'_noworkyeslook = 0 
	replace count_`i'_noworkyeslook = 1 if dummy_`i'==1 & dummy_age_`i'==1 & dummy_noworkyeslook_`i'==1
}

egen count_noworkyeslook_lf_f = rowtotal(count_0_noworkyeslook count_1_noworkyeslook count_2_noworkyeslook count_3_noworkyeslook count_4_noworkyeslook count_5_noworkyeslook count_6_noworkyeslook count_7_noworkyeslook count_8_noworkyeslook count_9_noworkyeslook count_10_noworkyeslook count_11_noworkyeslook)
label var count_noworkyeslook_lf_f "Number of females in labor force who are not working but is looking for work"

gen share_noworkyeslook_lf_f = count_noworkyeslook_lf_f/count_lf_fem*100
label var share_noworkyeslook_lf_f "Share of females in labor force who are not working but is looking for work"

forvalues i=0/11 {
	drop dummy_`i' dummy_age_`i' dummy_oaw_`i' count_`i'_oaw dummy_emp_`i' count_`i'_emp dummy_wage_`i' count_`i'_wage dummy_army_`i' count_`i'_army dummy_studwork_`i' count_`i'_studwork dummy_unpfam_`i' count_`i'_unpfam dummy_pfam_`i' count_`i'_pfam dummy_noworkyeslook_`i' count_`i'_noworkyeslook
}

**MALES**
forvalues i=0/11 {
	gen dummy_`i' = 0 
	replace dummy_`i' = 1 if inlist(relation`i',2, 4, 6, 7, 9) | inlist(relation`i',12, 13, 16, 17, 21)
}

forvalues i=0/11 {
	gen dummy_age_`i' = 0 
	replace dummy_age_`i' = 1 if age`i'>=18 & age`i'<=59
}

*Self-employed/own-account worker (no employees)
forvalues i=0/11 {
	gen dummy_oaw_`i' = 0 
	replace dummy_oaw_`i' = 1 if workstatus`i'==1
}

forvalues i=0/11 {
	gen count_`i'_oaw = 0 
	replace count_`i'_oaw = 1 if dummy_`i'==1 & dummy_age_`i'==1 & dummy_oaw_`i'==1
}

egen count_oaw_lf_m = rowtotal(count_0_oaw count_1_oaw count_2_oaw count_3_oaw count_4_oaw count_5_oaw count_6_oaw count_7_oaw count_8_oaw count_9_oaw count_10_oaw count_11_oaw)
label var count_oaw_lf_m "Number of males in labor force who are self-employed/own-account worker (no employees)"

gen share_oaw_lf_m = count_oaw_lf_m/count_lf_male*100
label var share_oaw_lf_m "Share of males in labor force who are self-employed/own-account worker (no employees)"

*Self-employed/business owner with at least 1 employee
forvalues i=0/11 {
	gen dummy_emp_`i' = 0 
	replace dummy_emp_`i' = 1 if workstatus`i'==2
}

forvalues i=0/11 {
	gen count_`i'_emp = 0 
	replace count_`i'_emp = 1 if dummy_`i'==1 & dummy_age_`i'==1 & dummy_emp_`i'==1
}

egen count_emp_lf_m = rowtotal(count_0_emp count_1_emp count_2_emp count_3_emp count_4_emp count_5_emp count_6_emp count_7_emp count_8_emp count_9_emp count_10_emp count_11_emp)
label var count_emp_lf_m "Number of males in labor force who are self-employed with at least 1 employee"

gen share_emp_lf_m = count_emp_lf_m/count_lf_male*100
label var share_emp_lf_m "Share of males in labor force who are self-employed with at least 1 employee"

*Salaried/wage employee
forvalues i=0/11 {
	gen dummy_wage_`i' = 0 
	replace dummy_wage_`i' = 1 if workstatus`i'==3
}

forvalues i=0/11 {
	gen count_`i'_wage = 0 
	replace count_`i'_wage = 1 if dummy_`i'==1 & dummy_age_`i'==1 & dummy_wage_`i'==1
}

egen count_wage_lf_m = rowtotal(count_0_wage count_1_wage count_2_wage count_3_wage count_4_wage count_5_wage count_6_wage count_7_wage count_8_wage count_9_wage count_10_wage count_11_wage)
label var count_wage_lf_m "Number of males in labor force who are salaried/wage wage employee"

gen share_wage_lf_m = count_wage_lf_m/count_lf_male*100
label var share_wage_lf_m "Share of males in labor force who are salaried/wage wage employee"

*Army
forvalues i=0/11 {
	gen dummy_army_`i' = 0 
	replace dummy_army_`i' = 1 if workstatus`i'==4
}

forvalues i=0/11 {
	gen count_`i'_army = 0 
	replace count_`i'_army = 1 if dummy_`i'==1 & dummy_age_`i'==1 & dummy_army_`i'==1
}

egen count_army_lf_m = rowtotal(count_0_army count_1_army count_2_army count_3_army count_4_army count_5_army count_6_army count_7_army count_8_army count_9_army count_10_army count_11_army)
label var count_army_lf_m "Number of males in labor force who are in the army"

gen share_army_lf_m = count_army_lf_m/count_lf_male*100
label var share_army_lf_m "Share of males in labor force who are in the army"

*Student who also works
forvalues i=0/11 {
	gen dummy_studwork_`i' = 0 
	replace dummy_studwork_`i' = 1 if workstatus`i'==5
}

forvalues i=0/11 {
	gen count_`i'_studwork = 0 
	replace count_`i'_studwork = 1 if dummy_`i'==1 & dummy_age_`i'==1 & dummy_studwork_`i'==1
}

egen count_studwork_lf_m = rowtotal(count_0_studwork count_1_studwork count_2_studwork count_3_studwork count_4_studwork count_5_studwork count_6_studwork count_7_studwork count_8_studwork count_9_studwork count_10_studwork count_11_studwork)
label var count_studwork_lf_m "Number of males in labor force who are students who also work"

gen share_studwork_lf_m = count_studwork_lf_m/count_lf_male*100
label var share_studwork_lf_m "Share of males in labor force who are students who also work"

*Unpaid worker in the family business
forvalues i=0/11 {
	gen dummy_unpfam_`i' = 0 
	replace dummy_unpfam_`i' = 1 if workstatus`i'==6
}

forvalues i=0/11 {
	gen count_`i'_unpfam = 0 
	replace count_`i'_unpfam = 1 if dummy_`i'==1 & dummy_age_`i'==1 & dummy_unpfam_`i'==1
}

egen count_unpfam_lf_m = rowtotal(count_0_unpfam count_1_unpfam count_2_unpfam count_3_unpfam count_4_unpfam count_5_unpfam count_6_unpfam count_7_unpfam count_8_unpfam count_9_unpfam count_10_unpfam count_11_unpfam)
label var count_unpfam_lf_m "Number of males in labor force who are unpaid workers in the family business"

gen share_unpfam_lf_m = count_unpfam_lf_m/count_lf_male*100
label var share_unpfam_lf_m "Share of males in labor force who are unpaid workers in the family business"

*Paid worker in the family business
forvalues i=0/11 {
	gen dummy_pfam_`i' = 0 
	replace dummy_pfam_`i' = 1 if workstatus`i'==7
}

forvalues i=0/11 {
	gen count_`i'_pfam = 0 
	replace count_`i'_pfam = 1 if dummy_`i'==1 & dummy_age_`i'==1 & dummy_pfam_`i'==1
}

egen count_pfam_lf_m = rowtotal(count_0_pfam count_1_pfam count_2_pfam count_3_pfam count_4_pfam count_5_pfam count_6_pfam count_7_pfam count_8_pfam count_9_pfam count_10_pfam count_11_pfam)
label var count_pfam_lf_m "Number of males in labor force who are paid workers in the family business"

gen share_pfam_lf_m = count_pfam_lf_m/count_lf_male*100
label var share_pfam_lf_m "Share of males in labor force who are paid workers in the family business"

*Does not work but is looking for work
forvalues i=0/11 {
	gen dummy_noworkyeslook_`i' = 0 
	replace dummy_noworkyeslook_`i' = 1 if workstatus`i'==10
}

forvalues i=0/11 {
	gen count_`i'_noworkyeslook = 0 
	replace count_`i'_noworkyeslook = 1 if dummy_`i'==1 & dummy_age_`i'==1 & dummy_noworkyeslook_`i'==1
}

egen count_noworkyeslook_lf_m = rowtotal(count_0_noworkyeslook count_1_noworkyeslook count_2_noworkyeslook count_3_noworkyeslook count_4_noworkyeslook count_5_noworkyeslook count_6_noworkyeslook count_7_noworkyeslook count_8_noworkyeslook count_9_noworkyeslook count_10_noworkyeslook count_11_noworkyeslook)
label var count_noworkyeslook_lf_m "Number of males in labor force who are not working but is looking for work"

gen share_noworkyeslook_lf_m = count_noworkyeslook_lf_m/count_lf_male*100
label var share_noworkyeslook_lf_m "Share of males in labor force who are not working but is looking for work"


forvalues i=0/11 {
	drop dummy_`i' dummy_age_`i' dummy_oaw_`i' count_`i'_oaw dummy_emp_`i' count_`i'_emp dummy_wage_`i' count_`i'_wage dummy_army_`i' count_`i'_army dummy_studwork_`i' count_`i'_studwork dummy_unpfam_`i' count_`i'_unpfam dummy_pfam_`i' count_`i'_pfam dummy_noworkyeslook_`i' count_`i'_noworkyeslook
}


**ALL**
forvalues i=0/11 {
	gen dummy_age_`i' = 0 
	replace dummy_age_`i' = 1 if age`i'>=18 & age`i'<=59
}

*Self-employed/own-account worker (no employees)
forvalues i=0/11 {
	gen dummy_oaw_`i' = 0 
	replace dummy_oaw_`i' = 1 if workstatus`i'==1
}

forvalues i=0/11 {
	gen count_`i'_oaw = 0 
	replace count_`i'_oaw = 1 if dummy_age_`i'==1 & dummy_oaw_`i'==1
}

egen count_lf_oaw = rowtotal(count_0_oaw count_1_oaw count_2_oaw count_3_oaw count_4_oaw count_5_oaw count_6_oaw count_7_oaw count_8_oaw count_9_oaw count_10_oaw count_11_oaw)
label var count_lf_oaw "Number of members in labor force who are self-employed/own-account worker (no employees)"

gen share_lf_oaw = count_lf_oaw/count_lf*100
label var share_lf_oaw "Share of members in labor force who are self-employed/own-account worker (no employees)"

*Self-employed/business owner with at least 1 employee
forvalues i=0/11 {
	gen dummy_emp_`i' = 0 
	replace dummy_emp_`i' = 1 if workstatus`i'==2
}

forvalues i=0/11 {
	gen count_`i'_emp = 0 
	replace count_`i'_emp = 1 if dummy_age_`i'==1 & dummy_emp_`i'==1
}

egen count_lf_emp = rowtotal(count_0_emp count_1_emp count_2_emp count_3_emp count_4_emp count_5_emp count_6_emp count_7_emp count_8_emp count_9_emp count_10_emp count_11_emp)
label var count_lf_emp "Number of members in labor force who are self-employed with at least 1 employee"

gen share_lf_emp = count_lf_emp/count_lf*100
label var share_lf_emp "Share of members in labor force who are self-employed with at least 1 employee"

*Salaried/wage employee
forvalues i=0/11 {
	gen dummy_wage_`i' = 0 
	replace dummy_wage_`i' = 1 if workstatus`i'==3
}

forvalues i=0/11 {
	gen count_`i'_wage = 0 
	replace count_`i'_wage = 1 if dummy_age_`i'==1 & dummy_wage_`i'==1
}

egen count_lf_wage = rowtotal(count_0_wage count_1_wage count_2_wage count_3_wage count_4_wage count_5_wage count_6_wage count_7_wage count_8_wage count_9_wage count_10_wage count_11_wage)
label var count_lf_wage "Number of members in labor force who are salaried/wage wage employee"

gen share_lf_wage = count_lf_wage/count_lf*100
label var share_lf_wage "Share of members in labor force who are salaried/wage wage employee"

*Army
forvalues i=0/11 {
	gen dummy_army_`i' = 0 
	replace dummy_army_`i' = 1 if workstatus`i'==4
}

forvalues i=0/11 {
	gen count_`i'_army = 0 
	replace count_`i'_army = 1 if dummy_age_`i'==1 & dummy_army_`i'==1
}

egen count_lf_army = rowtotal(count_0_army count_1_army count_2_army count_3_army count_4_army count_5_army count_6_army count_7_army count_8_army count_9_army count_10_army count_11_army)
label var count_lf_army "Number of members in labor force who are in the army"

gen share_lf_army = count_lf_army/count_lf*100
label var share_lf_army "Share of members in labor force who are in the army"

*Student who also works
forvalues i=0/11 {
	gen dummy_studwork_`i' = 0 
	replace dummy_studwork_`i' = 1 if workstatus`i'==5
}

forvalues i=0/11 {
	gen count_`i'_studwork = 0 
	replace count_`i'_studwork = 1 if dummy_age_`i'==1 & dummy_studwork_`i'==1
}

egen count_lf_studwork = rowtotal(count_0_studwork count_1_studwork count_2_studwork count_3_studwork count_4_studwork count_5_studwork count_6_studwork count_7_studwork count_8_studwork count_9_studwork count_10_studwork count_11_studwork)
label var count_lf_studwork "Number of members in labor force who are students who also work"

gen share_lf_studwork = count_lf_studwork/count_lf*100
label var share_lf_studwork "Share of members in labor force who are students who also work"

*Unpaid worker in the family business
forvalues i=0/11 {
	gen dummy_unpfam_`i' = 0 
	replace dummy_unpfam_`i' = 1 if workstatus`i'==6
}

forvalues i=0/11 {
	gen count_`i'_unpfam = 0 
	replace count_`i'_unpfam = 1 if dummy_age_`i'==1 & dummy_unpfam_`i'==1
}

egen count_lf_unpfam = rowtotal(count_0_unpfam count_1_unpfam count_2_unpfam count_3_unpfam count_4_unpfam count_5_unpfam count_6_unpfam count_7_unpfam count_8_unpfam count_9_unpfam count_10_unpfam count_11_unpfam)
label var count_lf_unpfam "Number of members in labor force who are unpaid workers in the family business"

gen share_lf_unpfam = count_lf_unpfam/count_lf*100
label var share_lf_unpfam "Share of members in labor force who are unpaid workers in the family business"

*Paid worker in the family business
forvalues i=0/11 {
	gen dummy_pfam_`i' = 0 
	replace dummy_pfam_`i' = 1 if workstatus`i'==7
}

forvalues i=0/11 {
	gen count_`i'_pfam = 0 
	replace count_`i'_pfam = 1 if dummy_age_`i'==1 & dummy_pfam_`i'==1
}

egen count_lf_pfam = rowtotal(count_0_pfam count_1_pfam count_2_pfam count_3_pfam count_4_pfam count_5_pfam count_6_pfam count_7_pfam count_8_pfam count_9_pfam count_10_pfam count_11_pfam)
label var count_lf_pfam "Number of members in labor force who are paid workers in the family business"

gen share_lf_pfam = count_lf_pfam/count_lf*100
label var share_lf_pfam "Share of members in labor force who are paid workers in the family business"

*Does not work but is looking for work
forvalues i=0/11 {
	gen dummy_noworkyeslook_`i' = 0 
	replace dummy_noworkyeslook_`i' = 1 if workstatus`i'==10
}

forvalues i=0/11 {
	gen count_`i'_noworkyeslook = 0 
	replace count_`i'_noworkyeslook = 1 if dummy_age_`i'==1 & dummy_noworkyeslook_`i'==1
}

egen count_lf_noworkyeslook = rowtotal(count_0_noworkyeslook count_1_noworkyeslook count_2_noworkyeslook count_3_noworkyeslook count_4_noworkyeslook count_5_noworkyeslook count_6_noworkyeslook count_7_noworkyeslook count_8_noworkyeslook count_9_noworkyeslook count_10_noworkyeslook count_11_noworkyeslook)
label var count_lf_noworkyeslook "Number of members in labor force who are not working but is looking for work"

gen share_lf_noworkyeslook = count_lf_noworkyeslook/count_lf*100
label var share_lf_noworkyeslook "Share of members in labor force who are not working but is looking for work"


forvalues i=0/11 {
	drop dummy_age_`i' dummy_oaw_`i' count_`i'_oaw dummy_emp_`i' count_`i'_emp dummy_wage_`i' count_`i'_wage dummy_army_`i' count_`i'_army dummy_studwork_`i' count_`i'_studwork dummy_unpfam_`i' count_`i'_unpfam dummy_pfam_`i' count_`i'_pfam dummy_noworkyeslook_`i' count_`i'_noworkyeslook
}

***********
*Does HH have male HH head? 
forvalues i=0/11 {
	gen dummy_`i' = 0 
	replace dummy_`i' = 1 if inlist(relation`i',2, 4, 6, 7, 9) | inlist(relation`i',12, 13, 16, 17, 21)
}

forvalues i=0/11 {
	gen dummy_head_`i' = 0 
	replace dummy_head_`i' = 1 if HHhead`i'==1
}

forvalues i=0/11 {
	gen MaleHHhead`i' = 0 
	replace MaleHHhead`i' = 1 if dummy_`i'==1 & dummy_head_`i'==1
}


gen MaleHHhead = 0 
forvalues i=0/11 {
	replace MaleHHhead = 1 if MaleHHhead`i'== 1 
}
label var MaleHHhead "Indicator for a male member as head of HH"
label val MaleHHhead yesno

forvalues i=0/11 {
	drop dummy_`i' dummy_head_`i' MaleHHhead`i' 
}

*Does MIL live in the HH?
forvalues i=0/11 {
	gen dummy_`i' = 0 
	replace dummy_`i' = 1 if relation`i'==5
}

gen MIL = 0 
forvalues i=0/11 {
	replace MIL = 1 if dummy_`i'== 1
}
label var MIL "Mother-in-law lives in the HH"
label val MIL yesno

forvalues i=0/11 {
	drop dummy_`i' 
}

*Does FIL live in the HH?
forvalues i=0/11 {
	gen dummy_`i' = 0 
	replace dummy_`i' = 1 if relation`i'==6
}

gen FIL = 0 
forvalues i=0/11 {
	replace FIL = 1 if dummy_`i'== 1
}
label var FIL "Father-in-law lives in the HH"
label val FIL yesno

forvalues i=0/11 {
	drop dummy_`i' 
}

*Do either MIL or FIL live in the HH? 
gen PIL = MIL 
replace PIL = FIL if MIL==0
label var PIL "At least one among MIL and FIL live in the HH"
label val PIL yesno


keep ID_HH count_hhmembers count_hhmembers_m count_hhmembers_f count_children count_children_female count_children_male count_childrenunder5 count_childrenunder18 count_workingage count_workingagefem count_workingagemale count_lf_s_fem count_lf_fem count_lf_s_male count_lf_male count_* share* MaleHHhead MIL FIL PIL

*save data 
save "$data\final\NPL_SN_FLFP_HH.dta", replace


}



********************************************************************************
*                  PART 3. Merging household-individual  				       *
********************************************************************************

if $part_3 {
	
 use "$data\intermediate\NPL_SN_FLFP.dta", clear 
 keep if gender==2
 keep ID_HH quota religion_family ethnicity ecological_zone locality hh_members hh_minors hh_seniors hh_disabled hh_migrants earn_inc_d_f intrem_inc_d_f domrem_inc_d_f transf_inc_d_f safety_inc_d_f savass_inc_d_f loan_inc_d_f earn_inc_f intrem_inc_f domrem_inc_f transf_inc_f safety_inc_f savass_inc_f loan_inc_f tot_inc_f
 save "$data\intermediate\NPL_SN_FLFP_FEMALE.dta", replace 

 use "$data\final\NPL_SN_FLFP_HH.dta", clear 
 merge 1:1 ID_HH using "$data\intermediate\NPL_SN_FLFP_FEMALE.dta"
 drop _merge 
 order ID_HH quota hh_members hh_minors hh_seniors hh_disabled hh_migrants
 save "$data\final\NPL_SN_FLFP_HH.dta", replace  
 
}

********************************************************************************
// END OF DOFILE
