* **************************************************************************** *
* **************************************************************************** *
* Women's Labor Force Participation in Nepal:                                  *
* An Exploration of The Role of Social Norms                                   *
* Replication .do files 													   * 
* 02: Data Construction .do file                                                   *
* 2024                                                                         *
* **************************************************************************** *
* **************************************************************************** *

/*
* Author: Aishwarya Patil
* Program Purpose: This dofile prepares the data for analysis. 
* Description: Key tasks performed by this dofile include:
- Generates variables required for regression analysis 
- Constructs indices of social norms   
*
* Date last modified: May 2024
*------------------------------------------------------------------------------*
* Datasets Required: 
* - NPL_SN_FLFP.dta 
*
* Unique Identificator:
* - ID
* - ID_HH
*
* Outline: 
*  Part 1. Generate outcome variables  
*  Part 2. Generate control variables required for analysis   
*  Part 3. Generate social norms indices 
*/


********************************************************************************
*                       PREPARATION AND MAIN SETTINGS 
********************************************************************************
if 1 {
* Index of parts
* -----------------  
  gl part_1    1   	// Generating outcome variables
  gl part_2    1    // Generating control variables
  gl part_3    1    // Constructing indices
  
}

********************************************************************************
*                  PART 1. Generating outcome variables	            		   *
********************************************************************************

if $part_1 {
	
*Load dataset 
 use "$data\intermediate\NPL_SN_FLFP.dta", clear
 
 keep ID_HH ID couple gender work_30days current_work_status work_ever paidwork_30days work_location
 keep if couple==1
 drop couple 

 gen lookforwork =0 
 replace lookforwork =1 if current_work_status==10
 label var lookforwork "Indicator for not working but looking for work"
 label val lookforwork yesno
 rename lookforwork lookforwork_marriedfem
 label var lookforwork_marriedfem "Looking for work: Self if female, wife's status if male"
 drop current_work_status

 keep if gender==2

 rename work_30days work30_marriedfem
 label var work30_marriedfem "Worked in past 30 days: Self if female, wife's status if male"

 rename paidwork_30days paidwork30_marriedfem
 label var paidwork30_marriedfem "Paid work in past 30 days: Self if fem, wife's if male"

 rename work_ever workedever_marriedfem
 label var workedever_marriedfem "Ever worked: Self if female, wife's status if male"

 rename work_location work_location_marriedfem
 label var work_location_marriedfem "Location of job: Self if female, wife's location if male"

 save "$data\intermediate\work_marriedfem.dta", replace 

 use "$data\intermediate\NPL_SN_FLFP.dta", clear
 merge m:1 ID_HH using "$data\intermediate\work_marriedfem.dta", keepusing(work30_marriedfem lookforwork_marriedfem paidwork30_marriedfem workedever_marriedfem work_location_marriedfem)
 drop _merge 

 gen working_fem = 0 
 replace working_fem = work_30days if gender==2
 replace working_fem = work30_marriedfem if gender==1 
 label var working_fem "Indicator for female (self/wife of male) worked in past 30 days"
 label val working_fem yesno	
 
 gen paidwork_fem = 0 
 replace paidwork_fem = paidwork_30days if gender==2
 replace paidwork_fem = paidwork30_marriedfem if gender==1
 replace paidwork_fem = 0 if missing(paidwork_fem)
 label var paidwork_fem "Indicator for female (self/wife of male) worked for pay in past 30 days"
 label val paidwork_fem yesno
 
 gen lookforwork_fem = 0 
 replace lookforwork_fem = 1 if gender==2 & current_work_status==10
 replace lookforwork_fem = lookforwork_marriedfem if gender==1 
 label var lookforwork_fem "Indicator for female (self/wife of male) looking for work"
 label val lookforwork_fem yesno	
 
 gen working_dependvar = 0 
 replace working_dependvar = 1 if working_fem==1 | lookforwork_fem==1
 label var working_dependvar "Female (self/wife of male) worked last 30 days or looking for work"
 label val working_dependvar yesno

 gen worklocation_fem = . 
 replace worklocation_fem = work_location if gender==2
 replace worklocation_fem = work_location_marriedfem if gender==1
 label var worklocation_fem "Female's (self/wife of male) location of current or last job"
 label define worklocation 1 "Home or structure attached to home" 2 "Outside home" 3 "Without fixed location/ Mobile" 4 "Both home and outside"
 label val worklocation_fem worklocation

*Since M1C is the outcome var and it is more intuitive to have 1 as yes, working, i.e., liberal, let's change it 
 gen flfp_outcome = 0 
 replace flfp_outcome = 1 if M1C==0
 label var flfp_outcome "Female works for pay outside the home (Individual Behavior)"
 label val flfp_outcome yesno

*save data 
 save "$data\final\NPL_SN_REGRESS.dta", replace 

}


********************************************************************************
*                  PART 2. Generating control variables	            		   *
********************************************************************************

if $part_2 {

*female 
 gen female = 0
 replace female = 1 if gender==2 
 label var female "Respondent is female"
 label val female yesno

*age squared 
 gen age_sq = age * age
 label var age_sq "Respodent's age in years, squared"
 
*age cut-off
 gen age_35 = 0 
 replace age_35 = 1 if age>=35
 label var age_35 "Indicator for age 35 years or above"

*education
 gen educ_years = 0 
 replace educ_years = 4 if education==2
 replace educ_years = 8 if education==3
 replace educ_years = 9.5 if education==4
 replace educ_years = 10 if education==5
 replace educ_years = 11.5 if education==6
 replace educ_years = 12 if education==7
 replace educ_years = 14.5 if education==8
 replace educ_years = 19.5 if education==9
 label var educ_years "years of education, derived from education level"
 
 gen educ_yrs_f = educ_years
 replace educ_yrs_f = . if female==0
 label var educ_yrs_f "years of education for females, derived from education level"
 gen educ_yrs_m = educ_years
 replace educ_yrs_m = . if female==1

*Bagmati province 
 gen bagmati = 0 
 replace bagmati = 1 if province==2
 label var bagmati "Respondent lives in Bagmati province"
 label val bagmati yesno 

*Madheshi ethnic group 
 gen madheshi = 0 
 replace madheshi = 1 if ethnicity == 3
 label var madheshi "Respodent belongs to Madheshi (non-Dalit) ethnic group"
 label val madheshi yesno

*urban 
 gen urban= 0 
 replace urban=1 if locality==1
 label var urban "Respondent lives in urban area"
 label val urban yesno

*log income 
 gen inc_hh = tot_inc_f
 replace inc_hh = tot_inc_m if gender==1
 label var inc_hh "Household's total income (NPR)"
 gen log_totinc_hh = log(inc_hh)
 label var log_totinc_hh "Log of household's total income (NPR)"
 summ log_totinc_hh inc_hh 		//4 respondetns (from 2 HHs) have reported 0 income, so change log var to 0 instead of missing 
 replace log_totinc_hh = 0 if inlist(ID_HH, "HH5921", "HH6107")
 
*HH income less income earned by working females 
 gen inc_hh_lessfem = inc_hh
 replace inc_hh_lessfem = inc_hh - work_inc_amt if female==1 & work_30days==1
 replace inc_hh_lessfem = inc_hh if missing(work_inc_amt) & female==1 & work_30days==1
 gen log_totinc_hhlessfem = log(inc_hh_lessfem)
 replace log_totinc_hhlessfem = 0 if missing(log_totinc_hhlessfem)
 drop inc_hh_lessfem
 label var log_totinc_hhlessfem "Log of household's total income less working females' earned income (NPR)"

//bring in HH-level vars 
 merge m:1 ID_HH using "$data\final\NPL_SN_FLFP_HH.dta", keepusing(count_children count_children_female count_children_male count_childrenunder5 count_childrenunder18 count_adolesgirls count_females10plusnotwork count_workingage count_workingagefem count_workingagemale count_lf_s_fem count_lf_fem count_lf_s_male count_lf_male MaleHHhead MIL FIL PIL)

 drop _merge

*has young children 
 gen child_under5 = 0 
 replace child_under5 = 1 if count_childrenunder5>0
 label var child_under5 "Indicator for respondent having child younger than 5 years"
 label val child_under5 yesno

 gen child_under18 = 0 
 replace child_under18 = 1 if count_childrenunder18>0
 label var child_under18 "Indicator for respondent having child younger than 18 years"
 label val child_under18 yesno

*use of childcare options 
 gen chcare_use = 0 
 replace chcare_use = 1 if chcare_inlaws_f==1 & gender==2 | chcare_spouse_f==1 & gender==2 | chcare_sib_f==1 & gender==2 | chcare_fam_f==1 & gender==2 | chcare_workp_f==1 & gender==2 | chcare_worknp_f==1 & gender==2 | chcare_center_f==1 & gender==2 | chcare_neig_f==1 & gender==2 | chcare_babysit_f==1 & gender==2
 replace chcare_use = 1 if  chcare_spouse_m ==1 & gender==1 | chcare_parents_m & gender==1 | chcare_sib_m & gender==1 | chcare_fam_m & gender==1 | chcare_workp_m & gender==1 | chcare_workpw_m & gender==1 | chcare_worknp_m & gender==1 | chcare_worknpw_m & gender==1 | chcare_center_m & gender==1 | chcare_neig_m & gender==1 | chcare_babysit_m & gender==1 
 replace chcare_use = . if chcare_na_f==1 & gender==2
 replace chcare_use = . if chcare_na_m==1 & gender==1
 label var chcare_use "Indicator for use of childcare options when working"
 label val chcare_use yesno

*female ever worked 
 gen ever_worked_fem = 0 
 replace ever_worked_fem = work_ever if gender==2
 replace ever_worked_fem = workedever_marriedfem if gender==1 
 label var ever_worked_fem "Indicator for female (self/wife of male) ever worked"
 label val ever_worked_fem yesno	

*ease of finding a job for not working or ever worked
 *codebook work_search_dur_exp_cat work_search_dur_exp2_cat, tab(100)
 //taking 2 months as the cut-off, finding job defined as easy (==1) if search duration <= 2 months 
 gen ease_jobsearch =0 
 replace ease_jobsearch =1 if inlist(work_search_dur_exp_cat, 1,2,3,4,5) | inlist(work_search_dur_exp2_cat, 1, 2, 3, 4, 5)
 replace ease_jobsearch = . if missing(work_search_dur_exp_cat) & missing(work_search_dur_exp2_cat)
 label var ease_jobsearch "Exp. job search duration<=2 mnths for not working or ever worked"
 label val ease_jobsearch yesno
 
*ease of finding job for working or have ever worked 
 gen ease_jobsearch_2mnths = 0 
 replace ease_jobsearch_2mnths = 1 if work_search_dur_cat<=5
 replace ease_jobsearch_2mnths = . if missing(work_search_dur_cat)
 label var ease_jobsearch_2mnths "Dummy for women who took <= 2 months to find a job (current or last)"
 label val ease_jobsearch_2mnths yesno
 
*availablity of resources to find work - other than networks/ family 
 gen job_srch_res_nonet = 0 
 replace job_srch_res_nonet = 1 if job_srch_res_online==1 | job_srch_res_agent==1 | job_srch_res_news==1 | job_srch_res_govt==1
 label var job_srch_res_nonet "Respondent is aware of non-network methods of job search"
 label val job_srch_res_nonet yesno
 
*method used to find current or last job being non-network
 gen job_srch_mthd_nonet = 0 if !missing(work_search_method)
 replace job_srch_mthd_nonet = 1 if inlist(work_search_method, 2,3,5,6)
 label var job_srch_mthd_nonet "Respodent used non-network methods to find job (curret or last)"
 label val job_srch_mthd_nonet yesno

*accessible, safe, convenient transportation  
 gen transport = 0 
 replace transport = 1 if work_travelmode_safe==1 | work_travelmode_conv==1 | work_travelmode_afford==1
 replace transport = . if missing(work_travelmode_safe)
 label var transport "Transportation to work is acessible &/or safe &/or convenient"
 label val transport yesno
 
*travel mode for women who are working or have ever worked 
 gen travel_sac = 0
 replace travel_sac = 1 if work_travelmode_safe==1 | work_travelmode_conv==1 | work_travelmode_afford==1
 replace travel_sac = 1 if worklocation_fem==1
 replace travel_sac = . if missing(work_location)
 label var travel_sac "Safe/accesible/convenient trasport to work, inc. 1 if wfh"
 label val travel_sac yesno

*written contract indicator for those looking for work 
 *codebook work_agreement if current_work_status==10
 gen written_contract = 0 if current_work_status==10
 replace written_contract = 1 if work_agreement==1 & current_work_status==10
 label var written_contract "Had written contract for those not working but looking for work"
 label val written_contract yesno
 
*written work agreemet for salaried or waged 
 gen written_agreement = 1 if !missing(work_agreement)
 replace written_agreement = 0 if work_agreement==2
 label var written_agreement "Respodent has/had written work agreement"
 label val written_agreement yesno
 
*written contract indicator all 
 recode work_agreement (1 = 1 "Written contract") (2 = 0 "Oral contract"), gen (work_written_contract)
 label var work_written_contract "Has written agreement for work"
 
*having at least 1 year (inc. permanent) contracts for salaried or waged 
 gen duration_agreement_1yr = 1 if !missing(work_agreement_dur) 
 replace duration_agreement_1yr = 0 if work_agreement_dur<=5
 label var duration_agreement_1yr "Respodent's work agreement duration is/was at least 1 year"
 label val duration_agreement_1yr yesno

*presence of other working-age women in the labor force (ex. studying) in the HH 
 *codebook count_lf_fem
 gen oth_fem_hh_lf_num = count_lf_fem
 replace oth_fem_hh_lf_num = count_lf_fem - 1 if quota==1
 label var oth_fem_hh_lf_num "Number of other working-age women in HH in labor force (ex. studying)"

 gen oth_fem_hh_lf = 0 
 replace oth_fem_hh_lf = 1 if oth_fem_hh_lf_num>0
 label var oth_fem_hh_lf "Presence of other working-age women in HH in labor force (ex. studying)"
 label val oth_fem_hh_lf yesno

*working_30 days only for females (for females working vs non-working)
 gen work_30_female = 0 
 replace work_30_female = 1 if work_30days==1 & female==1
 replace work_30_female = . if female==0
 label var work_30_female "Indicator for females worked in last 30 days"
 label val work_30_female yesno

*identify women in migrant vs non-migrant HHs
 gen mig_hh_female = 0 
 replace mig_hh_female = 1 if inlist(quota,3) & female==1
 replace mig_hh_female = . if female==0
 label var mig_hh_female "Indicator for females with migrant spouses"
 label val mig_hh_female yesno

*identify migrant vs non-migrant HHs
 gen mig_hh = mig_hh_female
 replace mig_hh = 0 if female==0
 label var mig_hh "Indicator for migrant HHs"
 
*identify male respondents who have ever migrated 
 gen ever_mig_male = 0 
 replace ever_mig_male = 1 if inlist(migrationstatus_male_self, 1,2,3,4,5)
 label var ever_mig_male "Indicator for male resp. ever migrated"
 label val ever_mig_male yesno

*presence of adolescent girls in the HH 
 gen adolescent_girls = 0 
 replace adolescent_girls = 1 if count_adolesgirls>0
 label var adolescent_girls "Indicator for adolescent girl(s) in respondent's HH"
 label val adolescent_girls yesno

*presence of other (ex. respondent) females in the HH who do not work and are >=10 years of age
 gen females10plusnotwork = 0 
 replace females10plusnotwork = 1 if count_females10plusnotwork>0
 label var females10plusnotwork "Indicator for other females (adolescents or older) in respondent's HH who are not working"
 label val females10plusnotwork yesno
 
 
*save data 
 save "$data\final\NPL_SN_REGRESS.dta", replace 
 
}


********************************************************************************
*                  PART 3. Generating social norms indices	            	   *
********************************************************************************

if $part_3 {

//WITHOUT Motherhood Norm  
global po_final M2A M2B M2C M2D M2E M2F M2H
global ne_final M3A M3B M3C M3D M3E M3F M3H
global ee_final M4A M4B M4C M4D M4E M4F M4H

*Personal Opinion 
egen po_indexsum_all = rsum($po_final)
label var po_indexsum_all "Personal Opinion Index"

*Normative Expectations  
egen ne_indexsum_all = rsum($ne_final)
label var ne_indexsum_all "Normative Expectations Index"

*Empirical Expectations 
egen ee_indexsum_all = rsum($ee_final)
label var ee_indexsum_all "Empirical Expectations Index"


*** INDICES SPLIT BY THEME ***
global po_hh M2A M2B
global po_public M2C M2D M2E M2F M2H
global ne_hh M3A M3B
global ne_public M3C M3D M3E M3F M3H
global ee_hh M4A M4B
global ee_public M4C M4D M4E M4F M4H

*<PO Index - HH Role>*
egen po_indexsum_hh = rsum($po_hh)
label var po_indexsum_hh "Personal Opinion Index - HH Roles"

egen po_indexsum_hh_f = rsum($po_hh) if female==1
label var po_indexsum_hh_f "Personal Opinion Index - HH Roles, Females"

egen po_indexsum_hh_m = rsum($po_hh) if female==0
label var po_indexsum_hh_m "Personal Opinion Index - HH Roles, Males"

*<PO Index - Public Sphere>*
egen po_indexsum_public = rsum($po_public)
label var po_indexsum_public "Personal Opinion Index - Public sphere"

egen po_indexsum_public_f = rsum($po_public) if female==1
label var po_indexsum_public_f "Personal Opinion Index - Public sphere, Females"

egen po_indexsum_public_m = rsum($po_public) if female==0
label var po_indexsum_public_m "Personal Opinion Index - Public sphere, Males"

*<NE Index - HH Role>*
egen ne_indexsum_hh = rsum($ne_hh)
label var ne_indexsum_hh "Normative Expectations Index - HH Roles"

egen ne_indexsum_hh_f = rsum($ne_hh) if female==1
label var ne_indexsum_hh_f "Normative Expectations Index - HH Roles, Females"

egen ne_indexsum_hh_m = rsum($ne_hh) if female==0
label var ne_indexsum_hh_m "Normative Expectations Index - HH Roles, Males"

*<NE Index - Public Sphere>*
egen ne_indexsum_public = rsum($ne_public)
label var ne_indexsum_public "Normative Expectations Index - Public sphere"

egen ne_indexsum_public_f = rsum($ne_public) if female==1
label var ne_indexsum_public_f "Normative Expectations Index - Public sphere, Females"

egen ne_indexsum_public_m = rsum($ne_public) if female==0
label var ne_indexsum_public_m "Normative Expectations Index - Public sphere, Males"

*<EE Index - HH Role>*
egen ee_indexsum_hh = rsum($ee_hh)
label var ee_indexsum_hh "Empirical Expectations Index - HH Roles"

egen ee_indexsum_hh_f = rsum($ee_hh) if female==1
label var ee_indexsum_hh_f "Empirical Expectations Index - HH Roles, Females"

egen ee_indexsum_hh_m = rsum($ee_hh) if female==0
label var ee_indexsum_hh_m "Empirical Expectations Index - HH Roles, Males"

*<EE Index - Public Sphere>*
egen ee_indexsum_public = rsum($ee_public)
label var ee_indexsum_public "Empirical Expectations Index - Public sphere"

egen ee_indexsum_public_f = rsum($ee_public) if female==1
label var ee_indexsum_public_f "Empirical Expectations Index - Public sphere, Females"

egen ee_indexsum_public_m = rsum($ee_public) if female==0
label var ee_indexsum_public_m "Empirical Expectations Index - Public sphere, Males"


*** SANCTIONS INDEX ***
egen sanc_indexsum = rsum(M5A M5B M5C M5D M5G M5H)
label var sanc_indexsum "Sanctions Index (includes childacre norm)"

egen sanc_indexsum_f = rsum(M5A M5B M5C M5D M5G M5H) if female==1
label var sanc_indexsum_f "Sanctions Index (includes childacre norm), Females"

egen sanc_indexsum_m = rsum(M5A M5B M5C M5D M5G M5H) if female==0
label var sanc_indexsum_m "Sanctions Index (includes childacre norm), Males" 

*save data 
 save "$data\final\NPL_SN_REGRESS.dta", replace 

}

********************************************************************************
// END OF DOFILE

